import { useState } from "react";
import { Dialog, DialogContent, DialogHeader, DialogTitle, DialogFooter } from "@/components/ui/dialog";
import { Button } from "@/components/ui/button";
import { FileUpload } from "@/components/ui/file-upload";
import { Input } from "@/components/ui/input";
import { Textarea } from "@/components/ui/textarea";
import { Label } from "@/components/ui/label";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { useForm } from "react-hook-form";
import { insertMovieSchema, InsertMovie } from "@shared/schema";
import { zodResolver } from "@hookform/resolvers/zod";
import { useMutation, useQueryClient } from "@tanstack/react-query";
import { apiRequest } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import { Form, FormControl, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { z } from "zod";
import { VideoExtractorModal } from "./video-extractor-modal";
import { Link2, Loader2 } from "lucide-react";

interface AddMovieModalProps {
  open: boolean;
  onOpenChange: (open: boolean) => void;
}

export function AddMovieModal({ open, onOpenChange }: AddMovieModalProps) {
  const { toast } = useToast();
  const queryClient = useQueryClient();
  const [posterFile, setPosterFile] = useState<File | null>(null);
  const [backdropFile, setBackdropFile] = useState<File | null>(null);
  const [fetchUrl, setFetchUrl] = useState("");
  const [fetchLoading, setFetchLoading] = useState(false);
  const [videoExtractorOpen, setVideoExtractorOpen] = useState(false);

  const formSchema = insertMovieSchema.extend({
    poster: z.any().optional(), // We'll handle file upload separately
    backdrop: z.any().optional(), // We'll handle file upload separately
  });

  const form = useForm<z.infer<typeof formSchema>>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      title: "",
      description: "",
      year: undefined,
      runtime: undefined,
      genre: "",
      contentRating: "",
      streamingUrl: "",
      externalSource: "",
      status: "active",
    },
  });

  const handleFetchExternalContent = async () => {
    if (!fetchUrl) return;

    setFetchLoading(true);
    try {
      // In a real app, this would fetch data from the external URL
      // and populate the form fields
      toast({
        title: "External fetch initiated",
        description: "Fetching content from external source...",
      });

      // Simulate API call
      await new Promise(resolve => setTimeout(resolve, 1500));

      // Simulate success with sample data
      form.setValue("title", "Fetched Movie Title");
      form.setValue("description", "This is a description fetched from an external source.");
      form.setValue("year", 2023);
      form.setValue("runtime", 120);
      form.setValue("genre", "Action");
      form.setValue("contentRating", "PG-13");
      form.setValue("streamingUrl", fetchUrl);
      form.setValue("externalSource", fetchUrl);

      toast({
        title: "Content fetched successfully",
        description: "The movie details have been populated from the external source.",
      });
    } catch (error) {
      toast({
        title: "Fetch failed",
        description: "Failed to fetch content from the external source.",
        variant: "destructive",
      });
    } finally {
      setFetchLoading(false);
    }
  };

  const movieMutation = useMutation({
    mutationFn: async (data: InsertMovie) => {
      // In a real implementation, this would handle file uploads and then save the movie
      const movieData = { ...data };
      
      // Simulate file upload and get URLs
      if (posterFile) {
        movieData.poster = URL.createObjectURL(posterFile);
      }
      
      if (backdropFile) {
        movieData.backdrop = URL.createObjectURL(backdropFile);
      }
      
      const res = await apiRequest("POST", "/api/movies", movieData);
      return await res.json();
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/movies'] });
      queryClient.invalidateQueries({ queryKey: ['/api/recent-content'] });
      queryClient.invalidateQueries({ queryKey: ['/api/stats'] });
      toast({
        title: "Movie added",
        description: "The movie has been added successfully."
      });
      onOpenChange(false);
      form.reset();
      setPosterFile(null);
      setBackdropFile(null);
      setFetchUrl("");
    },
    onError: (error) => {
      toast({
        title: "Failed to add movie",
        description: error instanceof Error ? error.message : "An error occurred while adding the movie.",
        variant: "destructive",
      });
    },
  });

  const onSubmit = (data: z.infer<typeof formSchema>) => {
    movieMutation.mutate(data as InsertMovie);
  };
  
  const handleSelectVideoUrl = (url: string) => {
    form.setValue("streamingUrl", url);
    toast({
      title: "Video link selected",
      description: "The streaming URL has been updated with the extracted link."
    });
  };

  return (
    <>
      <VideoExtractorModal
        open={videoExtractorOpen}
        onOpenChange={setVideoExtractorOpen}
        contentType="movie"
        onSelectVideoUrl={handleSelectVideoUrl}
      />
    
      <Dialog open={open} onOpenChange={onOpenChange}>
        <DialogContent className="max-w-2xl">
          <DialogHeader>
            <DialogTitle className="text-lg font-bold text-gray-800">Add New Movie</DialogTitle>
          </DialogHeader>
          
          <Form {...form}>
            <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6">
              <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                <FormField
                  control={form.control}
                  name="title"
                  render={({ field }) => (
                    <FormItem className="col-span-2">
                      <FormLabel>Title</FormLabel>
                      <FormControl>
                        <Input placeholder="Enter movie title" {...field} />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="year"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Year</FormLabel>
                      <FormControl>
                        <Input 
                          type="number" 
                          placeholder="Release year" 
                          {...field}
                          value={field.value || ''}
                          onChange={e => field.onChange(e.target.value ? parseInt(e.target.value) : undefined)}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="runtime"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Runtime (minutes)</FormLabel>
                      <FormControl>
                        <Input 
                          type="number" 
                          placeholder="Duration in minutes" 
                          {...field}
                          value={field.value || ''}
                          onChange={e => field.onChange(e.target.value ? parseInt(e.target.value) : undefined)}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="genre"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Genre</FormLabel>
                      <Select 
                        onValueChange={field.onChange} 
                        defaultValue={field.value}
                      >
                        <FormControl>
                          <SelectTrigger>
                            <SelectValue placeholder="Select genre" />
                          </SelectTrigger>
                        </FormControl>
                        <SelectContent>
                          <SelectItem value="action">Action</SelectItem>
                          <SelectItem value="comedy">Comedy</SelectItem>
                          <SelectItem value="drama">Drama</SelectItem>
                          <SelectItem value="horror">Horror</SelectItem>
                          <SelectItem value="sci-fi">Science Fiction</SelectItem>
                          <SelectItem value="thriller">Thriller</SelectItem>
                          <SelectItem value="romance">Romance</SelectItem>
                        </SelectContent>
                      </Select>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="contentRating"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Content Rating</FormLabel>
                      <Select 
                        onValueChange={field.onChange} 
                        defaultValue={field.value}
                      >
                        <FormControl>
                          <SelectTrigger>
                            <SelectValue placeholder="Select rating" />
                          </SelectTrigger>
                        </FormControl>
                        <SelectContent>
                          <SelectItem value="g">G</SelectItem>
                          <SelectItem value="pg">PG</SelectItem>
                          <SelectItem value="pg13">PG-13</SelectItem>
                          <SelectItem value="r">R</SelectItem>
                          <SelectItem value="nc17">NC-17</SelectItem>
                        </SelectContent>
                      </Select>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="description"
                  render={({ field }) => (
                    <FormItem className="col-span-2">
                      <FormLabel>Description</FormLabel>
                      <FormControl>
                        <Textarea 
                          placeholder="Movie description" 
                          className="resize-none" 
                          {...field} 
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <div>
                  <FileUpload
                    id="poster"
                    label="Poster Image"
                    accept="image/*"
                    maxSize={2}
                    onChange={setPosterFile}
                    error={form.formState.errors.poster?.message as string}
                  />
                </div>
                
                <div>
                  <FileUpload
                    id="backdrop"
                    label="Backdrop Image"
                    accept="image/*"
                    maxSize={2}
                    onChange={setBackdropFile}
                    error={form.formState.errors.backdrop?.message as string}
                  />
                </div>
                
                <FormField
                  control={form.control}
                  name="streamingUrl"
                  render={({ field }) => (
                    <FormItem className="col-span-2">
                      <FormLabel>Streaming URL</FormLabel>
                      <div className="flex space-x-2">
                        <FormControl>
                          <Input 
                            type="url" 
                            placeholder="https://example.com/video.mp4" 
                            {...field} 
                            className="flex-grow"
                          />
                        </FormControl>
                        <Button
                          type="button"
                          variant="outline"
                          onClick={() => setVideoExtractorOpen(true)}
                          className="flex-shrink-0"
                        >
                          <Link2 className="h-4 w-4 mr-1" /> Extract
                        </Button>
                      </div>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <div className="col-span-2">
                  <Label htmlFor="external-source">External Source</Label>
                  <div className="flex space-x-2">
                    <Input
                      id="external-source"
                      type="url"
                      placeholder="https://externalsource.com/movie-id"
                      value={fetchUrl}
                      onChange={(e) => setFetchUrl(e.target.value)}
                    />
                    <Button 
                      type="button" 
                      onClick={handleFetchExternalContent}
                      disabled={!fetchUrl || fetchLoading}
                    >
                      {fetchLoading ? (
                        <><Loader2 className="mr-2 h-4 w-4 animate-spin" /> Loading</>
                      ) : (
                        <>Fetch</>
                      )}
                    </Button>
                  </div>
                </div>
              </div>
              
              <DialogFooter className="flex justify-end space-x-3 pt-4 border-t border-gray-200">
                <Button 
                  type="button" 
                  variant="secondary" 
                  onClick={() => onOpenChange(false)}
                >
                  Cancel
                </Button>
                <Button 
                  type="submit" 
                  disabled={movieMutation.isPending}
                >
                  {movieMutation.isPending ? (
                    <><Loader2 className="mr-2 h-4 w-4 animate-spin" /> Saving</>
                  ) : (
                    <>Save Movie</>
                  )}
                </Button>
              </DialogFooter>
            </form>
          </Form>
        </DialogContent>
      </Dialog>
    </>
  );
}
