import { useState } from "react";
import { Dialog, DialogContent, DialogDescription, DialogFooter, DialogHeader, DialogTitle } from "@/components/ui/dialog";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { useMutation } from "@tanstack/react-query";
import { useToast } from "@/hooks/use-toast";
import { apiRequest } from "@/lib/queryClient";
import { Loader2, Copy, Check, ExternalLink } from "lucide-react";
import { Badge } from "@/components/ui/badge";

interface VideoExtractorModalProps {
  open: boolean;
  onOpenChange: (open: boolean) => void;
  contentType: "movie" | "series";
  onSelectVideoUrl?: (url: string) => void;
}

export function VideoExtractorModal({ 
  open, 
  onOpenChange, 
  contentType,
  onSelectVideoUrl
}: VideoExtractorModalProps) {
  const { toast } = useToast();
  const [sourceUrl, setSourceUrl] = useState("");
  const [activeTab, setActiveTab] = useState("extract");
  const [copiedIndex, setCopiedIndex] = useState<number | null>(null);
  const [selectedVideoIndex, setSelectedVideoIndex] = useState<number | null>(null);

  const extractVideoMutation = useMutation({
    mutationFn: async () => {
      const res = await apiRequest("POST", "/api/extract-video", { url: sourceUrl, type: contentType });
      return await res.json();
    },
    onSuccess: (data) => {
      toast({
        title: "Video links extracted",
        description: `Found ${data.videoLinks.length} playback options`,
      });
      setActiveTab("result");
      // Auto-select the first video link if available
      if (data.videoLinks.length > 0) {
        setSelectedVideoIndex(0);
      }
    },
    onError: (error) => {
      toast({
        title: "Extraction failed",
        description: error instanceof Error ? error.message : "An error occurred",
        variant: "destructive",
      });
    },
  });

  const handleCopyUrl = (url: string, index: number) => {
    navigator.clipboard.writeText(url).then(() => {
      setCopiedIndex(index);
      setTimeout(() => setCopiedIndex(null), 2000);
    });
  };

  const handleSelectVideo = (url: string, index: number) => {
    setSelectedVideoIndex(index);
    if (onSelectVideoUrl) {
      onSelectVideoUrl(url);
    }
  };

  const handleExtract = () => {
    if (!sourceUrl) {
      toast({
        title: "URL required",
        description: "Please enter the URL to extract video from",
        variant: "destructive",
      });
      return;
    }
    
    // Validate URL format
    try {
      new URL(sourceUrl);
    } catch (e) {
      toast({
        title: "Invalid URL",
        description: "Please enter a valid URL including http:// or https://",
        variant: "destructive",
      });
      return;
    }
    
    extractVideoMutation.mutate();
  };

  const videoData = extractVideoMutation.data;

  return (
    <Dialog open={open} onOpenChange={onOpenChange}>
      <DialogContent className="max-w-[650px] max-h-[90vh] overflow-y-auto">
        <DialogHeader>
          <DialogTitle>Video Link Extractor</DialogTitle>
          <DialogDescription>
            Extract playback links from external {contentType} sources
          </DialogDescription>
        </DialogHeader>

        <Tabs value={activeTab} onValueChange={setActiveTab}>
          <TabsList className="grid w-full grid-cols-2 mb-4">
            <TabsTrigger value="extract">Extract Video</TabsTrigger>
            <TabsTrigger 
              value="result" 
              disabled={!videoData || videoData.videoLinks.length === 0}
            >
              Results
            </TabsTrigger>
          </TabsList>
          
          <TabsContent value="extract" className="space-y-4">
            <div>
              <Label htmlFor="source-url">Source URL</Label>
              <div className="flex mt-2">
                <Input
                  id="source-url"
                  placeholder="https://example.com/watch/movie"
                  value={sourceUrl}
                  onChange={(e) => setSourceUrl(e.target.value)}
                  disabled={extractVideoMutation.isPending}
                  className="flex-grow mr-2"
                />
                <Button 
                  onClick={handleExtract}
                  disabled={extractVideoMutation.isPending || !sourceUrl}
                >
                  {extractVideoMutation.isPending ? (
                    <><Loader2 className="mr-2 h-4 w-4 animate-spin" /> Extracting</>
                  ) : (
                    'Extract'
                  )}
                </Button>
              </div>
              <p className="mt-2 text-sm text-muted-foreground">
                Enter the URL of a {contentType} page containing a video player
              </p>
            </div>

            <div className="bg-muted/40 rounded-lg p-4 mt-6">
              <h3 className="font-medium mb-2">Supported Sources</h3>
              <ul className="space-y-1 text-sm">
                <li className="flex items-center">
                  <Badge variant="secondary" className="mr-2">M3U8</Badge>
                  HLS streams from various providers
                </li>
                <li className="flex items-center">
                  <Badge variant="secondary" className="mr-2">MP4</Badge>
                  Direct video links from hosting sites
                </li>
                <li className="flex items-center">
                  <Badge variant="secondary" className="mr-2">MKV</Badge>
                  High-quality video files
                </li>
              </ul>
            </div>

            <div className="mt-4 text-sm text-muted-foreground">
              <p className="mb-1 font-medium">How it works:</p>
              <ol className="list-decimal list-inside space-y-1">
                <li>Enter the URL of a page that contains a video player</li>
                <li>Click "Extract" to analyze the page and find video links</li>
                <li>Select from available quality options</li>
                <li>Use the link in your {contentType} entry</li>
              </ol>
            </div>
          </TabsContent>
          
          <TabsContent value="result" className="space-y-4">
            {videoData && videoData.videoLinks.length > 0 ? (
              <>
                <div>
                  <Label>Source Website</Label>
                  <div className="flex items-center mt-1">
                    <Input value={videoData.sourceUrl} readOnly />
                    <Button 
                      variant="ghost" 
                      size="icon"
                      onClick={() => window.open(videoData.sourceUrl, '_blank')}
                      className="ml-2"
                    >
                      <ExternalLink className="h-4 w-4" />
                    </Button>
                  </div>
                </div>

                <div>
                  <Label>Available Video Links</Label>
                  <div className="space-y-2 mt-2">
                    {videoData.videoLinks.map((link, index) => (
                      <div 
                        key={index} 
                        className={`flex flex-col p-3 border rounded-md ${selectedVideoIndex === index ? 'border-primary bg-primary/5' : ''}`}
                      >
                        <div className="flex items-center justify-between mb-2">
                          <div className="flex items-center">
                            <Badge className="mr-2">{link.format}</Badge>
                            <span className="text-sm font-medium">{link.quality}</span>
                          </div>
                          <div className="flex items-center">
                            <Button 
                              variant="ghost" 
                              size="sm"
                              onClick={() => handleCopyUrl(link.url, index)}
                              className="h-8"
                            >
                              {copiedIndex === index ? (
                                <><Check className="h-4 w-4 mr-1" /> Copied</>
                              ) : (
                                <><Copy className="h-4 w-4 mr-1" /> Copy</>
                              )}
                            </Button>
                            <Button 
                              variant="outline" 
                              size="sm"
                              onClick={() => handleSelectVideo(link.url, index)}
                              className="h-8 ml-2"
                            >
                              {selectedVideoIndex === index ? 'Selected' : 'Select'}
                            </Button>
                          </div>
                        </div>
                        <Input 
                          value={link.url} 
                          readOnly 
                          className="text-xs font-mono"
                        />
                      </div>
                    ))}
                  </div>
                </div>
              </>
            ) : (
              <div className="text-center py-8">
                <p className="text-muted-foreground">No video links found.</p>
                <Button
                  variant="outline"
                  onClick={() => setActiveTab("extract")}
                  className="mt-4"
                >
                  Back to Extractor
                </Button>
              </div>
            )}
          </TabsContent>
        </Tabs>

        <DialogFooter className="flex flex-col sm:flex-row gap-2">
          {activeTab === "result" && videoData && videoData.videoLinks.length > 0 && (
            <Button 
              variant="secondary" 
              onClick={() => setActiveTab("extract")}
              className="sm:mr-auto"
            >
              Extract Another
            </Button>
          )}
          <Button 
            variant={activeTab === "extract" ? "outline" : "default"}
            onClick={() => {
              if (activeTab === "extract") {
                onOpenChange(false);
              } else if (selectedVideoIndex !== null && onSelectVideoUrl) {
                onOpenChange(false);
              } else {
                toast({
                  title: "No video selected",
                  description: "Please select a video link first",
                  variant: "destructive",
                });
              }
            }}
          >
            {activeTab === "extract" ? 'Cancel' : 'Use Selected Link'}
          </Button>
        </DialogFooter>
      </DialogContent>
    </Dialog>
  );
}