import { useEffect } from "react";
import { useAuth } from "@/hooks/use-auth";
import { useLocation } from "wouter";
import { z } from "zod";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { insertUserSchema } from "@shared/schema";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import {
  Card,
  CardContent,
  CardDescription,
  CardFooter,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from "@/components/ui/form";

const loginSchema = insertUserSchema.extend({
  username: z.string().min(3, {
    message: "Username must be at least 3 characters",
  }),
  password: z.string().min(6, {
    message: "Password must be at least 6 characters",
  }),
});

export default function AuthPage() {
  const { user, loginMutation } = useAuth();
  const [, navigate] = useLocation();

  useEffect(() => {
    if (user) {
      navigate("/dashboard");
    }
  }, [user, navigate]);

  const loginForm = useForm<z.infer<typeof loginSchema>>({
    resolver: zodResolver(loginSchema),
    defaultValues: {
      username: "",
      password: "",
    },
  });

  const onLogin = (values: z.infer<typeof loginSchema>) => {
    loginMutation.mutate({
      username: values.username,
      password: values.password,
    });
  };

  return (
    <div className="min-h-screen flex flex-col md:flex-row bg-gray-50">
      <div className="w-full md:w-1/2 flex items-center justify-center p-6">
        <Card className="w-full max-w-md">
          <CardHeader className="space-y-1">
            <div className="flex items-center justify-center mb-4">
              <i className="fas fa-play-circle text-primary text-3xl mr-2"></i>
              <h1 className="text-3xl font-bold text-primary">Saqr Admin</h1>
            </div>
            <CardTitle className="text-2xl text-center">
              Welcome back
            </CardTitle>
            <CardDescription className="text-center">
              Enter your credentials to access your account
            </CardDescription>
          </CardHeader>
          
          <Form {...loginForm}>
            <form onSubmit={loginForm.handleSubmit(onLogin)} className="space-y-4">
              <CardContent className="space-y-4">
                <FormField
                  control={loginForm.control}
                  name="username"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Username</FormLabel>
                      <FormControl>
                        <Input placeholder="Enter your username" {...field} />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                <FormField
                  control={loginForm.control}
                  name="password"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Password</FormLabel>
                      <FormControl>
                        <Input type="password" placeholder="••••••••" {...field} />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
              </CardContent>
              <CardFooter>
                <Button 
                  type="submit" 
                  className="w-full" 
                  disabled={loginMutation.isPending}
                >
                  {loginMutation.isPending ? "Signing in..." : "Sign In"}
                </Button>
              </CardFooter>
            </form>
          </Form>
        </Card>
      </div>
      
      <div className="w-full md:w-1/2 bg-primary hidden md:flex items-center justify-center p-6">
        <div className="max-w-md text-white">
          <h2 className="text-3xl font-bold mb-4">Manage Your Streaming Content</h2>
          <p className="mb-6">
            Saqr Admin provides powerful tools to manage all your streaming content - movies, TV series, live channels, 
            and sports matches in one place.
          </p>
          <ul className="space-y-2">
            <li className="flex items-center">
              <i className="fas fa-check-circle mr-2"></i>
              <span>Manage all your streaming content in one place</span>
            </li>
            <li className="flex items-center">
              <i className="fas fa-check-circle mr-2"></i>
              <span>Easily organize content with categories</span>
            </li>
            <li className="flex items-center">
              <i className="fas fa-check-circle mr-2"></i>
              <span>Fetch content from external sources</span>
            </li>
            <li className="flex items-center">
              <i className="fas fa-check-circle mr-2"></i>
              <span>Monitor usage with detailed statistics</span>
            </li>
          </ul>
        </div>
      </div>
    </div>
  );
}
