import { useState } from "react";
import { DashboardLayout } from "@/components/dashboard/layout";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { AddChannelModal } from "@/components/modals/add-channel-modal";
import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";
import { useToast } from "@/hooks/use-toast";
import { apiRequest } from "@/lib/queryClient";
import { Channel } from "@shared/schema";
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from "@/components/ui/table";
import { StatusBadge } from "@/components/ui/status-badge";
import { Loader2 } from "lucide-react";
import { AlertDialog, AlertDialogAction, AlertDialogCancel, AlertDialogContent, AlertDialogDescription, AlertDialogFooter, AlertDialogHeader, AlertDialogTitle } from "@/components/ui/alert-dialog";
import { format } from "date-fns";

export default function ChannelsPage() {
  const { toast } = useToast();
  const queryClient = useQueryClient();
  const [searchQuery, setSearchQuery] = useState("");
  const [typeFilter, setTypeFilter] = useState("all");
  const [showAddModal, setShowAddModal] = useState(false);
  const [channelToDelete, setChannelToDelete] = useState<Channel | null>(null);

  const { data: channels = [], isLoading } = useQuery({
    queryKey: ['/api/channels'],
  });

  const deleteChannelMutation = useMutation({
    mutationFn: async (id: number) => {
      await apiRequest("DELETE", `/api/channels/${id}`);
      return id;
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/channels'] });
      queryClient.invalidateQueries({ queryKey: ['/api/recent-content'] });
      queryClient.invalidateQueries({ queryKey: ['/api/stats'] });
      toast({
        title: "Channel deleted",
        description: "The channel has been successfully deleted.",
      });
    },
    onError: (error) => {
      toast({
        title: "Failed to delete channel",
        description: error.message || "An error occurred while deleting the channel.",
        variant: "destructive",
      });
    },
  });

  const filteredChannels = channels.filter(channel => {
    const matchesSearch = channel.name?.toLowerCase().includes(searchQuery.toLowerCase());
    const matchesType = typeFilter === 'all' || channel.type === typeFilter;
    return matchesSearch && matchesType;
  });

  const uniqueTypes = Array.from(new Set(channels.map(channel => channel.type).filter(Boolean)));

  const handleDeleteChannel = (channel: Channel) => {
    setChannelToDelete(channel);
  };

  const confirmDelete = () => {
    if (channelToDelete) {
      deleteChannelMutation.mutate(channelToDelete.id);
      setChannelToDelete(null);
    }
  };

  return (
    <DashboardLayout
      title="Live Channels"
      subtitle="Manage your live TV channels"
    >
      <div className="mb-6 flex flex-col md:flex-row gap-4 justify-between">
        <div className="flex flex-col md:flex-row gap-4 md:items-center">
          <Input
            placeholder="Search channels..."
            className="max-w-sm"
            value={searchQuery}
            onChange={(e) => setSearchQuery(e.target.value)}
          />
          <Select value={typeFilter} onValueChange={setTypeFilter}>
            <SelectTrigger className="max-w-[200px]">
              <SelectValue placeholder="All Types" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="all">All Types</SelectItem>
              {uniqueTypes.map(type => (
                <SelectItem key={type} value={type as string}>{type}</SelectItem>
              ))}
            </SelectContent>
          </Select>
        </div>
        <Button onClick={() => setShowAddModal(true)}>
          <i className="fas fa-plus mr-2"></i> Add Channel
        </Button>
      </div>

      <div className="bg-white rounded-lg shadow-sm overflow-hidden">
        {isLoading ? (
          <div className="flex justify-center items-center p-12">
            <Loader2 className="h-8 w-8 animate-spin text-primary" />
          </div>
        ) : filteredChannels.length === 0 ? (
          <div className="flex flex-col items-center justify-center p-12 text-center">
            <i className="fas fa-broadcast-tower text-gray-300 text-5xl mb-4"></i>
            <h3 className="text-lg font-medium text-gray-900 mb-1">No channels found</h3>
            <p className="text-gray-500 mb-4">
              {searchQuery || typeFilter !== 'all'
                ? "Try adjusting your search or filter criteria"
                : "Start adding live channels to your collection"}
            </p>
            {!(searchQuery || typeFilter !== 'all') && (
              <Button onClick={() => setShowAddModal(true)}>
                <i className="fas fa-plus mr-2"></i> Add Your First Channel
              </Button>
            )}
          </div>
        ) : (
          <Table>
            <TableHeader>
              <TableRow>
                <TableHead>Channel</TableHead>
                <TableHead>Type</TableHead>
                <TableHead>Status</TableHead>
                <TableHead>Stream URL</TableHead>
                <TableHead>Added On</TableHead>
                <TableHead className="text-right">Actions</TableHead>
              </TableRow>
            </TableHeader>
            <TableBody>
              {filteredChannels.map((channel) => (
                <TableRow key={channel.id}>
                  <TableCell className="font-medium">
                    <div className="flex items-center">
                      {channel.logo ? (
                        <div
                          className="h-10 w-10 rounded bg-cover bg-center mr-3"
                          style={{ backgroundImage: `url(${channel.logo})` }}
                        ></div>
                      ) : (
                        <div className="h-10 w-10 rounded bg-gray-200 flex items-center justify-center mr-3">
                          <i className="fas fa-broadcast-tower text-gray-400"></i>
                        </div>
                      )}
                      {channel.name}
                    </div>
                  </TableCell>
                  <TableCell className="capitalize">{channel.type || "N/A"}</TableCell>
                  <TableCell>
                    <StatusBadge status={(channel.status as any) || "active"} />
                  </TableCell>
                  <TableCell>
                    {channel.streamingUrl ? (
                      <div className="max-w-xs truncate">
                        {channel.streamingUrl}
                      </div>
                    ) : "N/A"}
                  </TableCell>
                  <TableCell>
                    {channel.createdAt ? format(new Date(channel.createdAt), 'MMM d, yyyy') : "N/A"}
                  </TableCell>
                  <TableCell className="text-right">
                    <div className="flex justify-end space-x-2">
                      <Button variant="ghost" size="icon" title="Edit">
                        <i className="fas fa-edit text-gray-500 hover:text-primary"></i>
                      </Button>
                      <Button 
                        variant="ghost" 
                        size="icon" 
                        title="Delete" 
                        onClick={() => handleDeleteChannel(channel)}
                      >
                        <i className="fas fa-trash text-gray-500 hover:text-red-500"></i>
                      </Button>
                    </div>
                  </TableCell>
                </TableRow>
              ))}
            </TableBody>
          </Table>
        )}
      </div>

      <AddChannelModal
        open={showAddModal}
        onOpenChange={setShowAddModal}
      />

      <AlertDialog open={!!channelToDelete} onOpenChange={() => setChannelToDelete(null)}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>Are you sure?</AlertDialogTitle>
            <AlertDialogDescription>
              This action cannot be undone. This will permanently delete
              the channel "{channelToDelete?.name}" from your collection.
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel>Cancel</AlertDialogCancel>
            <AlertDialogAction onClick={confirmDelete} className="bg-red-500 hover:bg-red-600">
              {deleteChannelMutation.isPending ? "Deleting..." : "Delete"}
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </DashboardLayout>
  );
}
