import { useState } from "react";
import { DashboardLayout } from "@/components/dashboard/layout";
import { StatsCard } from "@/components/dashboard/stats-card";
import { ContentTable, ContentItem } from "@/components/dashboard/content-table";
import { QuickActions } from "@/components/dashboard/quick-actions";
import { Notifications } from "@/components/dashboard/notifications";
import { AddMovieModal } from "@/components/modals/add-movie-modal";
import { AddSeriesModal } from "@/components/modals/add-series-modal";
import { AddChannelModal } from "@/components/modals/add-channel-modal";
import { AddMatchModal } from "@/components/modals/add-match-modal";
import { useQuery, useMutation } from "@tanstack/react-query";
import { useAuth } from "@/hooks/use-auth";
import { useToast } from "@/hooks/use-toast";
import { AlertDialog, AlertDialogAction, AlertDialogCancel, AlertDialogContent, AlertDialogDescription, AlertDialogFooter, AlertDialogHeader, AlertDialogTitle } from "@/components/ui/alert-dialog";
import { apiRequest } from "@/lib/queryClient";

export default function DashboardPage() {
  const { user } = useAuth();
  const { toast } = useToast();
  const [showAddMovieModal, setShowAddMovieModal] = useState(false);
  const [showAddSeriesModal, setShowAddSeriesModal] = useState(false);
  const [showAddChannelModal, setShowAddChannelModal] = useState(false);
  const [showAddMatchModal, setShowAddMatchModal] = useState(false);
  const [showFetchModal, setShowFetchModal] = useState(false);
  const [itemToDelete, setItemToDelete] = useState<ContentItem | null>(null);
  const [fetchUrl, setFetchUrl] = useState("");

  // Query for dashboard stats
  const { data: stats, isLoading: statsLoading } = useQuery({
    queryKey: ['/api/stats'],
    enabled: !!user,
  });

  // Query for recent content
  const { data: recentContent = [], isLoading: contentLoading } = useQuery({
    queryKey: ['/api/recent-content'],
    enabled: !!user,
  });

  // Query for notifications
  const { data: notifications = [], isLoading: notificationsLoading } = useQuery({
    queryKey: ['/api/notifications'],
    enabled: !!user,
  });

  const deleteContentMutation = useMutation({
    mutationFn: async (item: ContentItem) => {
      let endpoint = '';
      if ('year' in item) endpoint = `/api/movies/${item.id}`;
      else if ('startYear' in item) endpoint = `/api/series/${item.id}`;
      else if ('streamingUrl' in item && 'sport' in item) endpoint = `/api/matches/${item.id}`;
      else endpoint = `/api/channels/${item.id}`;
      
      await apiRequest("DELETE", endpoint);
      return item.id;
    },
    onSuccess: () => {
      toast({
        title: "Content deleted",
        description: "The item has been successfully deleted.",
      });
      
      // Refetch recent content and stats
      queryClient.invalidateQueries({ queryKey: ['/api/recent-content'] });
      queryClient.invalidateQueries({ queryKey: ['/api/stats'] });
    },
    onError: (error) => {
      toast({
        title: "Failed to delete content",
        description: error.message || "An error occurred while deleting the content.",
        variant: "destructive",
      });
    },
  });

  const markAllNotificationsReadMutation = useMutation({
    mutationFn: async () => {
      // In a real implementation, this would call an API endpoint to mark all notifications as read
      // For now, we'll simulate it
      if (notifications && notifications.length > 0) {
        for (const notification of notifications) {
          await apiRequest("PATCH", `/api/notifications/${notification.id}/read`);
        }
      }
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/notifications'] });
      toast({
        title: "Notifications marked as read",
        description: "All notifications have been marked as read.",
      });
    },
    onError: () => {
      toast({
        title: "Failed to mark notifications as read",
        description: "An error occurred while updating notifications.",
        variant: "destructive",
      });
    },
  });

  const handleEdit = (item: ContentItem) => {
    if ('year' in item) {
      // Movie
      // In a full implementation, this would open the edit modal with existing data
      toast({
        title: "Edit Movie",
        description: `Edit functionality for "${item.title}" will be implemented in a future update.`,
      });
    } else if ('startYear' in item) {
      // Series
      toast({
        title: "Edit Series",
        description: `Edit functionality for "${item.title}" will be implemented in a future update.`,
      });
    } else if ('streamingUrl' in item && 'sport' in item) {
      // Match
      toast({
        title: "Edit Match",
        description: `Edit functionality for "${item.title}" will be implemented in a future update.`,
      });
    } else {
      // Channel
      toast({
        title: "Edit Channel",
        description: `Edit functionality for "${item.name}" will be implemented in a future update.`,
      });
    }
  };

  const handleDelete = (item: ContentItem) => {
    setItemToDelete(item);
  };

  const confirmDelete = () => {
    if (itemToDelete) {
      deleteContentMutation.mutate(itemToDelete);
      setItemToDelete(null);
    }
  };

  const cancelDelete = () => {
    setItemToDelete(null);
  };

  return (
    <DashboardLayout 
      title="Dashboard" 
      subtitle={`Welcome back, ${user?.username}! Here's an overview of your content.`}
    >
      {/* Stats Cards */}
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6 mb-8">
        <StatsCard
          title="Movies"
          value={statsLoading ? "..." : stats?.movies || 0}
          icon="film"
          iconBgColor="bg-blue-100"
          iconColor="text-primary"
        />
        <StatsCard
          title="TV Series"
          value={statsLoading ? "..." : stats?.series || 0}
          icon="tv"
          iconBgColor="bg-green-100"
          iconColor="text-success"
        />
        <StatsCard
          title="Live Channels"
          value={statsLoading ? "..." : stats?.channels || 0}
          icon="broadcast-tower"
          iconBgColor="bg-orange-100"
          iconColor="text-warning"
        />
        <StatsCard
          title="Live Matches"
          value={statsLoading ? "..." : stats?.matches || 0}
          icon="futbol"
          iconBgColor="bg-red-100"
          iconColor="text-error"
        />
      </div>

      <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
        {/* Recent Content */}
        <div className="lg:col-span-2">
          <ContentTable
            items={recentContent}
            onEdit={handleEdit}
            onDelete={handleDelete}
          />
        </div>

        {/* Quick Actions and Notifications */}
        <div className="space-y-6">
          <QuickActions
            onAddMovie={() => setShowAddMovieModal(true)}
            onAddSeries={() => setShowAddSeriesModal(true)}
            onAddChannel={() => setShowAddChannelModal(true)}
            onFetchContent={() => setShowFetchModal(true)}
          />

          <Notifications
            notifications={notifications}
            onMarkAllRead={() => markAllNotificationsReadMutation.mutate()}
          />
        </div>
      </div>

      {/* Modals */}
      <AddMovieModal
        open={showAddMovieModal}
        onOpenChange={setShowAddMovieModal}
      />
      
      <AddSeriesModal
        open={showAddSeriesModal}
        onOpenChange={setShowAddSeriesModal}
      />
      
      <AddChannelModal
        open={showAddChannelModal}
        onOpenChange={setShowAddChannelModal}
      />
      
      <AddMatchModal
        open={showAddMatchModal}
        onOpenChange={setShowAddMatchModal}
      />

      {/* Delete Confirmation Dialog */}
      <AlertDialog open={!!itemToDelete} onOpenChange={cancelDelete}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>Are you sure?</AlertDialogTitle>
            <AlertDialogDescription>
              This action cannot be undone. This will permanently delete the selected content
              and remove the data from our servers.
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel>Cancel</AlertDialogCancel>
            <AlertDialogAction onClick={confirmDelete} className="bg-red-500 hover:bg-red-600">
              {deleteContentMutation.isPending ? "Deleting..." : "Delete"}
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </DashboardLayout>
  );
}
