import { useState } from "react";
import { DashboardLayout } from "@/components/dashboard/layout";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { useMutation } from "@tanstack/react-query";
import { useToast } from "@/hooks/use-toast";
import { apiRequest } from "@/lib/queryClient";
import { Loader2 } from "lucide-react";

export default function FetcherPage() {
  const { toast } = useToast();
  const [activeTab, setActiveTab] = useState<string>("url");
  const [fetchUrl, setFetchUrl] = useState("");
  const [contentType, setContentType] = useState<string>("movie");
  const [bulkUrls, setBulkUrls] = useState("");

  const fetchContentMutation = useMutation({
    mutationFn: async ({ url, type }: { url: string; type: string }) => {
      const res = await apiRequest("POST", "/api/fetch-external", { url, type });
      return await res.json();
    },
    onSuccess: () => {
      toast({
        title: "Fetch initiated",
        description: "The system has started fetching content. You'll be notified when it's complete.",
      });
    },
    onError: (error) => {
      toast({
        title: "Fetch failed",
        description: error.message || "An error occurred while trying to fetch content.",
        variant: "destructive",
      });
    },
  });

  const bulkFetchMutation = useMutation({
    mutationFn: async ({ urls, type }: { urls: string[]; type: string }) => {
      // In a real implementation, this would process multiple URLs
      // For now, we'll just simulate it with a notification
      
      toast({
        title: "Bulk fetch initiated",
        description: `Started processing ${urls.length} URLs. This may take some time.`,
      });
      
      // Simulate the process for each URL
      for (const url of urls) {
        await fetchContentMutation.mutateAsync({ url, type });
      }
      
      return { success: true, count: urls.length };
    },
    onSuccess: (data) => {
      toast({
        title: "Bulk fetch completed",
        description: `Processed ${data.count} URLs. Check notifications for details.`,
      });
      setBulkUrls("");
    },
    onError: (error) => {
      toast({
        title: "Bulk fetch failed",
        description: error.message || "An error occurred during bulk processing.",
        variant: "destructive",
      });
    },
  });

  const handleFetchContent = () => {
    if (!fetchUrl) {
      toast({
        title: "URL required",
        description: "Please enter a URL to fetch content from.",
        variant: "destructive",
      });
      return;
    }
    
    fetchContentMutation.mutate({ url: fetchUrl, type: contentType });
  };

  const handleBulkFetch = () => {
    if (!bulkUrls.trim()) {
      toast({
        title: "URLs required",
        description: "Please enter at least one URL to fetch content from.",
        variant: "destructive",
      });
      return;
    }
    
    const urls = bulkUrls.split('\n').filter(url => url.trim() !== '');
    
    if (urls.length === 0) {
      toast({
        title: "URLs required",
        description: "Please enter at least one valid URL.",
        variant: "destructive",
      });
      return;
    }
    
    bulkFetchMutation.mutate({ urls, type: contentType });
  };

  return (
    <DashboardLayout
      title="Content Fetcher"
      subtitle="Fetch content from external sources"
    >
      <div className="grid grid-cols-1 lg:grid-cols-3 gap-6 mb-8">
        <Card className="lg:col-span-2">
          <CardHeader>
            <CardTitle>Fetch Content</CardTitle>
            <CardDescription>
              Enter the URL of an external source to fetch content automatically
            </CardDescription>
          </CardHeader>
          <CardContent>
            <Tabs value={activeTab} onValueChange={setActiveTab}>
              <TabsList className="grid w-full grid-cols-2 mb-4">
                <TabsTrigger value="url">Single URL</TabsTrigger>
                <TabsTrigger value="bulk">Bulk Import</TabsTrigger>
              </TabsList>
              
              <TabsContent value="url" className="space-y-4">
                <div>
                  <Label htmlFor="content-type">Content Type</Label>
                  <Select value={contentType} onValueChange={setContentType}>
                    <SelectTrigger className="mt-1">
                      <SelectValue placeholder="Select content type" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="movie">Movie</SelectItem>
                      <SelectItem value="series">TV Series</SelectItem>
                      <SelectItem value="channel">Channel</SelectItem>
                      <SelectItem value="match">Live Match</SelectItem>
                    </SelectContent>
                  </Select>
                </div>
                
                <div>
                  <Label htmlFor="fetch-url">External URL</Label>
                  <div className="flex mt-1">
                    <Input
                      id="fetch-url"
                      placeholder="https://example.com/content"
                      value={fetchUrl}
                      onChange={(e) => setFetchUrl(e.target.value)}
                      className="flex-grow mr-2"
                    />
                    <Button 
                      onClick={handleFetchContent}
                      disabled={fetchContentMutation.isPending || !fetchUrl}
                    >
                      {fetchContentMutation.isPending ? (
                        <><Loader2 className="mr-2 h-4 w-4 animate-spin" /> Fetching</>
                      ) : (
                        <><i className="fas fa-download mr-2"></i> Fetch</>
                      )}
                    </Button>
                  </div>
                </div>
              </TabsContent>
              
              <TabsContent value="bulk" className="space-y-4">
                <div>
                  <Label htmlFor="content-type-bulk">Content Type</Label>
                  <Select value={contentType} onValueChange={setContentType}>
                    <SelectTrigger className="mt-1">
                      <SelectValue placeholder="Select content type" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="movie">Movie</SelectItem>
                      <SelectItem value="series">TV Series</SelectItem>
                      <SelectItem value="channel">Channel</SelectItem>
                      <SelectItem value="match">Live Match</SelectItem>
                    </SelectContent>
                  </Select>
                </div>
                
                <div>
                  <Label htmlFor="bulk-urls">URLs (one per line)</Label>
                  <textarea
                    id="bulk-urls"
                    placeholder="https://example.com/content1&#10;https://example.com/content2&#10;https://example.com/content3"
                    value={bulkUrls}
                    onChange={(e) => setBulkUrls(e.target.value)}
                    className="w-full h-40 px-3 py-2 mt-1 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-primary focus:border-transparent"
                  />
                </div>
                
                <Button 
                  onClick={handleBulkFetch}
                  disabled={bulkFetchMutation.isPending || !bulkUrls.trim()}
                  className="w-full"
                >
                  {bulkFetchMutation.isPending ? (
                    <><Loader2 className="mr-2 h-4 w-4 animate-spin" /> Processing</>
                  ) : (
                    <><i className="fas fa-cloud-download-alt mr-2"></i> Import All</>
                  )}
                </Button>
              </TabsContent>
            </Tabs>
          </CardContent>
        </Card>
        
        <Card>
          <CardHeader>
            <CardTitle>Fetching Guide</CardTitle>
            <CardDescription>How to use the content fetcher</CardDescription>
          </CardHeader>
          <CardContent>
            <div className="space-y-4">
              <div>
                <h3 className="font-semibold text-sm mb-1">Supported Sources</h3>
                <ul className="text-sm space-y-1 text-gray-600 list-disc pl-5">
                  <li>IMDb movie and show pages</li>
                  <li>YouTube videos and channels</li>
                  <li>Sports streaming sites</li>
                  <li>News channel streams</li>
                </ul>
              </div>
              
              <div>
                <h3 className="font-semibold text-sm mb-1">Format Requirements</h3>
                <ul className="text-sm space-y-1 text-gray-600 list-disc pl-5">
                  <li>URLs must include the protocol (http:// or https://)</li>
                  <li>Make sure to select the correct content type</li>
                  <li>For bulk import, add one URL per line</li>
                </ul>
              </div>
              
              <div>
                <h3 className="font-semibold text-sm mb-1">What Gets Imported</h3>
                <ul className="text-sm space-y-1 text-gray-600 list-disc pl-5">
                  <li>Title, description, and images</li>
                  <li>Release year and duration</li>
                  <li>Genre and content rating</li>
                  <li>Streaming URL when available</li>
                </ul>
              </div>
            </div>
          </CardContent>
          <CardFooter className="flex flex-col items-start">
            <p className="text-sm text-gray-500 mb-4">
              Content fetching happens in the background. 
              Check the notifications for progress and results.
            </p>
            <Button variant="outline" className="w-full">
              <i className="fas fa-question-circle mr-2"></i> View Full Documentation
            </Button>
          </CardFooter>
        </Card>
      </div>
      
      <Card>
        <CardHeader>
          <CardTitle>Recent Fetch History</CardTitle>
          <CardDescription>Recently fetched content from external sources</CardDescription>
        </CardHeader>
        <CardContent>
          <div className="text-center py-8 text-gray-500">
            <i className="fas fa-history text-4xl mb-3"></i>
            <p>No recent fetch history available</p>
            <p className="text-sm mt-1">After you fetch content, it will appear here</p>
          </div>
        </CardContent>
      </Card>
    </DashboardLayout>
  );
}
