import { useState } from "react";
import { DashboardLayout } from "@/components/dashboard/layout";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { AddSeriesModal } from "@/components/modals/add-series-modal";
import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";
import { useToast } from "@/hooks/use-toast";
import { apiRequest } from "@/lib/queryClient";
import { Series } from "@shared/schema";
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from "@/components/ui/table";
import { StatusBadge } from "@/components/ui/status-badge";
import { Loader2 } from "lucide-react";
import { AlertDialog, AlertDialogAction, AlertDialogCancel, AlertDialogContent, AlertDialogDescription, AlertDialogFooter, AlertDialogHeader, AlertDialogTitle } from "@/components/ui/alert-dialog";
import { format } from "date-fns";

export default function SeriesPage() {
  const { toast } = useToast();
  const queryClient = useQueryClient();
  const [searchQuery, setSearchQuery] = useState("");
  const [genreFilter, setGenreFilter] = useState("all");
  const [showAddModal, setShowAddModal] = useState(false);
  const [seriesToDelete, setSeriesToDelete] = useState<Series | null>(null);

  const { data: seriesList = [], isLoading } = useQuery({
    queryKey: ['/api/series'],
  });

  const deleteSeriesMutation = useMutation({
    mutationFn: async (id: number) => {
      await apiRequest("DELETE", `/api/series/${id}`);
      return id;
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/series'] });
      queryClient.invalidateQueries({ queryKey: ['/api/recent-content'] });
      queryClient.invalidateQueries({ queryKey: ['/api/stats'] });
      toast({
        title: "Series deleted",
        description: "The series has been successfully deleted.",
      });
    },
    onError: (error) => {
      toast({
        title: "Failed to delete series",
        description: error.message || "An error occurred while deleting the series.",
        variant: "destructive",
      });
    },
  });

  const filteredSeries = seriesList.filter(series => {
    const matchesSearch = series.title?.toLowerCase().includes(searchQuery.toLowerCase());
    const matchesGenre = genreFilter === 'all' || series.genre === genreFilter;
    return matchesSearch && matchesGenre;
  });

  const uniqueGenres = Array.from(new Set(seriesList.map(series => series.genre).filter(Boolean)));

  const handleDeleteSeries = (series: Series) => {
    setSeriesToDelete(series);
  };

  const confirmDelete = () => {
    if (seriesToDelete) {
      deleteSeriesMutation.mutate(seriesToDelete.id);
      setSeriesToDelete(null);
    }
  };

  return (
    <DashboardLayout
      title="TV Series"
      subtitle="Manage your TV series collection"
    >
      <div className="mb-6 flex flex-col md:flex-row gap-4 justify-between">
        <div className="flex flex-col md:flex-row gap-4 md:items-center">
          <Input
            placeholder="Search series..."
            className="max-w-sm"
            value={searchQuery}
            onChange={(e) => setSearchQuery(e.target.value)}
          />
          <Select value={genreFilter} onValueChange={setGenreFilter}>
            <SelectTrigger className="max-w-[200px]">
              <SelectValue placeholder="All Genres" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="all">All Genres</SelectItem>
              {uniqueGenres.map(genre => (
                <SelectItem key={genre} value={genre as string}>{genre}</SelectItem>
              ))}
            </SelectContent>
          </Select>
        </div>
        <Button onClick={() => setShowAddModal(true)}>
          <i className="fas fa-plus mr-2"></i> Add Series
        </Button>
      </div>

      <div className="bg-white rounded-lg shadow-sm overflow-hidden">
        {isLoading ? (
          <div className="flex justify-center items-center p-12">
            <Loader2 className="h-8 w-8 animate-spin text-primary" />
          </div>
        ) : filteredSeries.length === 0 ? (
          <div className="flex flex-col items-center justify-center p-12 text-center">
            <i className="fas fa-tv text-gray-300 text-5xl mb-4"></i>
            <h3 className="text-lg font-medium text-gray-900 mb-1">No series found</h3>
            <p className="text-gray-500 mb-4">
              {searchQuery || genreFilter !== 'all'
                ? "Try adjusting your search or filter criteria"
                : "Start adding TV series to your collection"}
            </p>
            {!(searchQuery || genreFilter !== 'all') && (
              <Button onClick={() => setShowAddModal(true)}>
                <i className="fas fa-plus mr-2"></i> Add Your First Series
              </Button>
            )}
          </div>
        ) : (
          <Table>
            <TableHeader>
              <TableRow>
                <TableHead>Title</TableHead>
                <TableHead>Years</TableHead>
                <TableHead>Genre</TableHead>
                <TableHead>Status</TableHead>
                <TableHead>Rating</TableHead>
                <TableHead>Added On</TableHead>
                <TableHead className="text-right">Actions</TableHead>
              </TableRow>
            </TableHeader>
            <TableBody>
              {filteredSeries.map((series) => (
                <TableRow key={series.id}>
                  <TableCell className="font-medium">
                    <div className="flex items-center">
                      {series.poster ? (
                        <div
                          className="h-10 w-10 rounded bg-cover bg-center mr-3"
                          style={{ backgroundImage: `url(${series.poster})` }}
                        ></div>
                      ) : (
                        <div className="h-10 w-10 rounded bg-gray-200 flex items-center justify-center mr-3">
                          <i className="fas fa-tv text-gray-400"></i>
                        </div>
                      )}
                      {series.title}
                    </div>
                  </TableCell>
                  <TableCell>
                    {series.startYear ? 
                      (series.endYear ? `${series.startYear} - ${series.endYear}` : `${series.startYear} - Present`) : 
                      "N/A"
                    }
                  </TableCell>
                  <TableCell>{series.genre || "N/A"}</TableCell>
                  <TableCell>
                    <StatusBadge status={(series.status as any) || "active"} />
                  </TableCell>
                  <TableCell>{series.contentRating || "N/A"}</TableCell>
                  <TableCell>
                    {series.createdAt ? format(new Date(series.createdAt), 'MMM d, yyyy') : "N/A"}
                  </TableCell>
                  <TableCell className="text-right">
                    <div className="flex justify-end space-x-2">
                      <Button variant="ghost" size="icon" title="Edit">
                        <i className="fas fa-edit text-gray-500 hover:text-primary"></i>
                      </Button>
                      <Button 
                        variant="ghost" 
                        size="icon" 
                        title="Delete" 
                        onClick={() => handleDeleteSeries(series)}
                      >
                        <i className="fas fa-trash text-gray-500 hover:text-red-500"></i>
                      </Button>
                    </div>
                  </TableCell>
                </TableRow>
              ))}
            </TableBody>
          </Table>
        )}
      </div>

      <AddSeriesModal
        open={showAddModal}
        onOpenChange={setShowAddModal}
      />

      <AlertDialog open={!!seriesToDelete} onOpenChange={() => setSeriesToDelete(null)}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>Are you sure?</AlertDialogTitle>
            <AlertDialogDescription>
              This action cannot be undone. This will permanently delete
              the series "{seriesToDelete?.title}" from your collection.
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel>Cancel</AlertDialogCancel>
            <AlertDialogAction onClick={confirmDelete} className="bg-red-500 hover:bg-red-600">
              {deleteSeriesMutation.isPending ? "Deleting..." : "Delete"}
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </DashboardLayout>
  );
}
