import { useForm } from "react-hook-form";
import { Button } from "@/components/ui/button";
import React from "react";
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { Textarea } from "@/components/ui/textarea";
import { Switch } from "@/components/ui/switch";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { useMutation, useQuery, useQueryClient } from "@tanstack/react-query";
import { InsertSiteSettings, SiteSettings } from "@shared/schema";
import { zodResolver } from "@hookform/resolvers/zod";
import { z } from "zod";
import { FileUpload } from "@/components/ui/file-upload";
import { apiRequest, queryClient } from "@/lib/queryClient";
import { DashboardLayout } from "@/components/dashboard/layout";
import { Loader2, Shield, Download, Smartphone, Upload } from "lucide-react";
import { useToast } from "@/hooks/use-toast";
import { useAuth } from "@/hooks/use-auth";
import { Alert, AlertDescription, AlertTitle } from "@/components/ui/alert";
import { Progress } from "@/components/ui/progress";
import { Label } from "@/components/ui/label";
import path from "path-browserify";

// App upload form schema
const AppUploadSchema = z.object({
  appFile: z.instanceof(File).refine(file => file.size < 100 * 1024 * 1024, {
    message: "App file must be smaller than 100MB"
  }),
  appVersion: z.string().min(1, "Version is required")
});

type AppUploadFormValues = z.infer<typeof AppUploadSchema>;

// AppUploadForm component
const AppUploadForm = ({ settings }: { settings?: any }): React.ReactNode => {
  const { toast } = useToast();
  const [uploading, setUploading] = React.useState(false);
  const [uploadProgress, setUploadProgress] = React.useState(0);
  const [appFile, setAppFile] = React.useState<File | null>(null);
  const [appVersion, setAppVersion] = React.useState("");
  
  // Handle file selection
  const handleFileChange = (file: File | null) => {
    setAppFile(file);
    
    // Extract version from filename if possible (like saqr-tv-1.2.3.apk)
    if (file) {
      const versionMatch = file.name.match(/(\d+\.\d+(\.\d+)?)/);
      if (versionMatch && !appVersion) {
        setAppVersion(versionMatch[0]);
      }
    }
  };
  
  // Handle form submission
  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    
    if (!appFile) {
      toast({
        title: "No file selected",
        description: "Please select an APK file to upload",
        variant: "destructive"
      });
      return;
    }
    
    try {
      // Validate with schema
      AppUploadSchema.parse({ appFile, appVersion });
      
      // Create FormData object
      const formData = new FormData();
      formData.append("appFile", appFile);
      formData.append("appVersion", appVersion);
      
      setUploading(true);
      setUploadProgress(0);
      
      // Upload with progress tracking
      const xhr = new XMLHttpRequest();
      xhr.open("POST", "/api/app/upload");
      
      xhr.upload.addEventListener("progress", (event) => {
        if (event.lengthComputable) {
          const progress = Math.round((event.loaded / event.total) * 100);
          setUploadProgress(progress);
        }
      });
      
      xhr.onload = () => {
        if (xhr.status >= 200 && xhr.status < 300) {
          setUploading(false);
          toast({
            title: "App uploaded successfully",
            description: `Saqr TV v${appVersion} is now available for download`,
          });
          
          // Reset form
          setAppFile(null);
          setAppVersion("");
          setUploadProgress(0);
          
          // Refresh settings data
          queryClient.invalidateQueries({ queryKey: ["/api/settings"] });
        } else {
          throw new Error("Upload failed");
        }
      };
      
      xhr.onerror = () => {
        throw new Error("Network error");
      };
      
      xhr.onabort = () => {
        setUploading(false);
        toast({
          title: "Upload cancelled",
          description: "The file upload was cancelled",
          variant: "destructive"
        });
      };
      
      xhr.send(formData);
      
    } catch (error) {
      setUploading(false);
      
      if (error instanceof z.ZodError) {
        toast({
          title: "Validation error",
          description: error.errors[0].message,
          variant: "destructive"
        });
      } else if (error instanceof Error) {
        toast({
          title: "Upload failed",
          description: error.message,
          variant: "destructive"
        });
      }
    }
  };
  
  // Render the form
  return (
    <div className="space-y-6">
      <form onSubmit={handleSubmit} className="space-y-4">
        <div className="space-y-2">
          <Label htmlFor="app-file">Upload APK File</Label>
          <FileUpload
            id="app-file"
            label="Select APK File"
            accept=".apk"
            maxSize={100}
            onChange={handleFileChange}
          />
          {appFile && (
            <p className="text-sm text-muted-foreground">
              Selected file: {appFile.name} ({Math.round(appFile.size / 1024 / 1024 * 10) / 10}MB)
            </p>
          )}
        </div>
        
        <div className="space-y-2">
          <Label htmlFor="app-version">Version</Label>
          <Input
            id="app-version"
            value={appVersion}
            onChange={(e) => setAppVersion(e.target.value)}
            placeholder="1.0.0"
            className="max-w-xs"
            required
          />
          <p className="text-sm text-muted-foreground">
            Enter the version number for this release
          </p>
        </div>
        
        {uploading && (
          <div className="space-y-2">
            <Progress value={uploadProgress} className="h-2 w-full" />
            <p className="text-xs text-muted-foreground text-center">
              Uploading... {uploadProgress}%
            </p>
          </div>
        )}
        
        <Button 
          type="submit"
          disabled={uploading || !appFile || !appVersion}
          className="mt-4"
        >
          {uploading ? (
            <Loader2 className="mr-2 h-4 w-4 animate-spin" />
          ) : (
            <Upload className="mr-2 h-4 w-4" />
          )}
          Upload APK
        </Button>
      </form>
    </div>
  );
};

// Define the form schema with validation
const SettingsFormSchema = z.object({
  siteName: z.string().min(1, "Site name is required"),
  siteDescription: z.string().min(1, "Site description is required"),
  siteKeywords: z.string().min(1, "Site keywords are required"),
  maintenance: z.boolean().default(false),
  siteLogo: z.any().optional(),
  siteFavicon: z.any().optional(),
});

// Password reset form schema
const PasswordResetSchema = z.object({
  currentPassword: z.string().min(6, "Current password must be at least 6 characters"),
  newPassword: z.string().min(6, "New password must be at least 6 characters"),
  confirmPassword: z.string().min(6, "Confirm password must be at least 6 characters"),
}).refine((data) => data.newPassword === data.confirmPassword, {
  message: "Passwords do not match",
  path: ["confirmPassword"],
});

type SettingsFormValues = z.infer<typeof SettingsFormSchema>;
type PasswordResetValues = z.infer<typeof PasswordResetSchema>;

export default function SettingsPage() {
  const queryClient = useQueryClient();
  const { toast } = useToast();
  const { user } = useAuth();
  const [activeTab, setActiveTab] = React.useState("general");
  
  // Fetch settings data
  const { data: settings, isLoading } = useQuery<SiteSettings>({
    queryKey: ["/api/settings"],
    queryFn: ({ signal }) => 
      fetch("/api/settings", { signal })
        .then(res => {
          if (!res.ok) throw new Error("Failed to fetch settings");
          return res.json();
        }),
  });

  // Create form with validation
  const form = useForm<SettingsFormValues>({
    resolver: zodResolver(SettingsFormSchema),
    defaultValues: {
      siteName: settings?.siteName || "",
      siteDescription: settings?.siteDescription || "",
      siteKeywords: settings?.siteKeywords || "",
      maintenance: settings?.maintenance || false,
    },
  });
  
  // Create password reset form
  const passwordForm = useForm<PasswordResetValues>({
    resolver: zodResolver(PasswordResetSchema),
    defaultValues: {
      currentPassword: "",
      newPassword: "",
      confirmPassword: "",
    },
  });

  // Update form values when settings are loaded
  React.useEffect(() => {
    if (settings) {
      form.reset({
        siteName: settings.siteName,
        siteDescription: settings.siteDescription,
        siteKeywords: settings.siteKeywords,
        maintenance: settings.maintenance,
        // We don't set the logo/favicon here since they're files
      });
    }
  }, [settings, form]);

  // Update settings mutation
  const updateSettings = useMutation({
    mutationFn: async (values: SettingsFormValues) => {
      const updatedSettings: Partial<InsertSiteSettings> = {
        ...values,
      };
      
      // If we have a new logo/favicon (File objects), we'd handle them here
      // This would typically involve uploading the files to a server
      // and then setting the URLs in the settings
      
      const res = await apiRequest("PATCH", "/api/settings", updatedSettings);
      return await res.json();
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ["/api/settings"] });
      toast({
        title: "Settings updated",
        description: "Your site settings have been updated successfully.",
      });
    },
    onError: (error) => {
      toast({
        title: "Failed to update settings",
        description: error.message,
        variant: "destructive",
      });
    },
  });
  
  // Password reset mutation
  const resetPassword = useMutation({
    mutationFn: async (values: PasswordResetValues) => {
      const res = await apiRequest("POST", "/api/reset-password", {
        currentPassword: values.currentPassword,
        newPassword: values.newPassword,
      });
      
      if (!res.ok) {
        const error = await res.json();
        throw new Error(error.message || "Failed to reset password");
      }
      
      return await res.json();
    },
    onSuccess: () => {
      passwordForm.reset({
        currentPassword: "",
        newPassword: "",
        confirmPassword: "",
      });
      
      toast({
        title: "Password updated",
        description: "Your password has been updated successfully.",
      });
    },
    onError: (error) => {
      toast({
        title: "Failed to update password",
        description: error.message,
        variant: "destructive",
      });
    },
  });

  // Form submission handlers
  const onSubmit = (values: SettingsFormValues) => {
    updateSettings.mutate(values);
  };
  
  const onPasswordSubmit = (values: PasswordResetValues) => {
    resetPassword.mutate(values);
  };

  if (isLoading) {
    return (
      <DashboardLayout title="Settings">
        <div className="flex justify-center items-center min-h-[400px]">
          <Loader2 className="h-8 w-8 animate-spin text-primary" />
        </div>
      </DashboardLayout>
    );
  }

  return (
    <DashboardLayout title="Site Settings" subtitle="Manage your site's information and appearance">
      <Card className="w-full max-w-4xl mx-auto">
        <CardHeader>
          <CardTitle>Site Configuration</CardTitle>
          <CardDescription>
            Update your site's information, security settings, and appearance
          </CardDescription>
        </CardHeader>
        <CardContent>
          <Tabs value={activeTab} onValueChange={setActiveTab} className="w-full">
            <TabsList className="mb-6">
              <TabsTrigger value="general">General Settings</TabsTrigger>
              <TabsTrigger value="security">Security</TabsTrigger>
              <TabsTrigger value="app">App Upload</TabsTrigger>
            </TabsList>
            
            <TabsContent value="general">
              <Form {...form}>
                <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6">
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <FormField
                      control={form.control}
                      name="siteName"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Site Name</FormLabel>
                          <FormControl>
                            <Input placeholder="Saqr TV" {...field} />
                          </FormControl>
                          <FormDescription>
                            This will be displayed in the browser tab and throughout the site
                          </FormDescription>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <FormField
                      control={form.control}
                      name="maintenance"
                      render={({ field }) => (
                        <FormItem className="flex flex-row items-center justify-between mt-8 space-y-0">
                          <div className="space-y-0.5">
                            <FormLabel>Maintenance Mode</FormLabel>
                            <FormDescription>
                              When enabled, the site will display a maintenance page
                            </FormDescription>
                          </div>
                          <FormControl>
                            <Switch
                              checked={field.value}
                              onCheckedChange={field.onChange}
                            />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                  </div>
                  
                  <FormField
                    control={form.control}
                    name="siteDescription"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>Site Description</FormLabel>
                        <FormControl>
                          <Textarea
                            placeholder="A streaming platform for movies, series, channels and live matches"
                            className="resize-none min-h-[100px]"
                            {...field}
                          />
                        </FormControl>
                        <FormDescription>
                          This will be used for SEO and displayed in search results
                        </FormDescription>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                  
                  <FormField
                    control={form.control}
                    name="siteKeywords"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>Site Keywords</FormLabel>
                        <FormControl>
                          <Input
                            placeholder="streaming, movies, series, tv, channels, live matches"
                            {...field}
                          />
                        </FormControl>
                        <FormDescription>
                          Comma-separated keywords to improve your site's search ranking
                        </FormDescription>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                  
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <FormField
                      control={form.control}
                      name="siteLogo"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Site Logo</FormLabel>
                          <FormControl>
                            <FileUpload
                              id="site-logo"
                              label="Upload Logo"
                              accept="image/*"
                              maxSize={2} // 2MB
                              onChange={field.onChange}
                            />
                          </FormControl>
                          <FormDescription>
                            Recommended size: 200x50 pixels (PNG or SVG)
                          </FormDescription>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <FormField
                      control={form.control}
                      name="siteFavicon"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Site Favicon</FormLabel>
                          <FormControl>
                            <FileUpload
                              id="site-favicon"
                              label="Upload Favicon"
                              accept=".ico,.png"
                              maxSize={1} // 1MB
                              onChange={field.onChange}
                            />
                          </FormControl>
                          <FormDescription>
                            Recommended size: 32x32 pixels (ICO or PNG)
                          </FormDescription>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                  </div>
                  
                  <CardFooter className="flex justify-end px-0 pb-0">
                    <Button 
                      type="submit" 
                      disabled={updateSettings.isPending}
                    >
                      {updateSettings.isPending && (
                        <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                      )}
                      Save Changes
                    </Button>
                  </CardFooter>
                </form>
              </Form>
            </TabsContent>
            
            <TabsContent value="security">
              <Card>
                <CardHeader className="pb-2">
                  <div className="flex items-center">
                    <Shield className="h-5 w-5 mr-2 text-primary" />
                    <CardTitle>Admin Password</CardTitle>
                  </div>
                  <CardDescription>
                    Change your administrator password
                  </CardDescription>
                </CardHeader>
                <CardContent>
                  <Form {...passwordForm}>
                    <form onSubmit={passwordForm.handleSubmit(onPasswordSubmit)} className="space-y-6">
                      <FormField
                        control={passwordForm.control}
                        name="currentPassword"
                        render={({ field }) => (
                          <FormItem>
                            <FormLabel>Current Password</FormLabel>
                            <FormControl>
                              <Input 
                                type="password" 
                                placeholder="Enter your current password" 
                                {...field} 
                              />
                            </FormControl>
                            <FormMessage />
                          </FormItem>
                        )}
                      />
                      
                      <FormField
                        control={passwordForm.control}
                        name="newPassword"
                        render={({ field }) => (
                          <FormItem>
                            <FormLabel>New Password</FormLabel>
                            <FormControl>
                              <Input 
                                type="password" 
                                placeholder="Enter your new password" 
                                {...field} 
                              />
                            </FormControl>
                            <FormDescription>
                              Password must be at least 6 characters long
                            </FormDescription>
                            <FormMessage />
                          </FormItem>
                        )}
                      />
                      
                      <FormField
                        control={passwordForm.control}
                        name="confirmPassword"
                        render={({ field }) => (
                          <FormItem>
                            <FormLabel>Confirm New Password</FormLabel>
                            <FormControl>
                              <Input 
                                type="password" 
                                placeholder="Confirm your new password" 
                                {...field} 
                              />
                            </FormControl>
                            <FormMessage />
                          </FormItem>
                        )}
                      />
                      
                      <Button 
                        type="submit" 
                        className="w-full"
                        disabled={resetPassword.isPending}
                      >
                        {resetPassword.isPending && (
                          <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                        )}
                        Change Password
                      </Button>
                    </form>
                  </Form>
                </CardContent>
              </Card>
              
              <Card className="mt-6">
                <CardHeader className="pb-2">
                  <CardTitle>Account Security</CardTitle>
                  <CardDescription>
                    Additional security information
                  </CardDescription>
                </CardHeader>
                <CardContent>
                  <div className="space-y-4">
                    <div className="flex justify-between items-center pb-2 border-b">
                      <div>
                        <h4 className="font-medium">Registration Status</h4>
                        <p className="text-sm text-muted-foreground">New user registration is locked</p>
                      </div>
                      <div className="px-3 py-1 bg-primary/10 text-primary rounded-full text-sm">
                        Locked
                      </div>
                    </div>
                    
                    <div className="flex justify-between items-center pb-2 border-b">
                      <div>
                        <h4 className="font-medium">Admin Account</h4>
                        <p className="text-sm text-muted-foreground">
                          {user?.username || "Admin"}
                        </p>
                      </div>
                      <div className="px-3 py-1 bg-green-500/10 text-green-500 rounded-full text-sm">
                        Active
                      </div>
                    </div>
                    
                    <div className="flex justify-between items-center">
                      <div>
                        <h4 className="font-medium">Last Login</h4>
                        <p className="text-sm text-muted-foreground">
                          {new Date().toLocaleString()}
                        </p>
                      </div>
                    </div>
                  </div>
                </CardContent>
              </Card>
            </TabsContent>
            
            <TabsContent value="app">
              <Card>
                <CardHeader>
                  <div className="flex items-center">
                    <Smartphone className="h-5 w-5 mr-2 text-primary" />
                    <CardTitle>Saqr TV App Upload</CardTitle>
                  </div>
                  <CardDescription>
                    Upload the Android APK file for users to download
                  </CardDescription>
                </CardHeader>
                <CardContent className="space-y-6">
                  {/* App File Upload Form */}
                  <AppUploadForm settings={settings} />
                  
                  {/* App Download Info */}
                  {settings?.appFilePath && (
                    <div className="mt-8 border rounded-md p-4">
                      <div className="flex flex-col space-y-3">
                        <Alert>
                          <Smartphone className="h-4 w-4 mr-2" />
                          <AlertTitle>Saqr TV App is available for download</AlertTitle>
                          <AlertDescription>
                            Current version: {settings.appVersion || "1.0.0"}
                          </AlertDescription>
                        </Alert>
                        
                        <div className="flex items-center justify-between pt-2">
                          <div className="flex-1">
                            <h4 className="font-medium text-base">File Information</h4>
                            <p className="text-sm text-muted-foreground">
                              {settings.appFileName || "saqr-tv.apk"}
                            </p>
                          </div>
                          <Button 
                            variant="outline" 
                            size="sm"
                            onClick={() => window.open(`/uploads/${settings.appFilePath ? path.basename(settings.appFilePath) : 'app.apk'}`, '_blank')}
                          >
                            <Download className="h-4 w-4 mr-2" />
                            Download
                          </Button>
                        </div>
                      </div>
                    </div>
                  )}
                </CardContent>
              </Card>
            </TabsContent>
            
          </Tabs>
        </CardContent>
      </Card>
    </DashboardLayout>
  );
}