import React, { ReactNode } from "react";
import { Link } from "wouter";
import { Button } from "@/components/ui/button";
import { 
  Home, 
  Info, 
  HelpCircle, 
  MessageSquare, 
  Menu, 
  X 
} from "lucide-react";
import { Sheet, SheetContent, SheetTrigger } from "@/components/ui/sheet";

interface PublicLayoutProps {
  children: ReactNode;
  title?: string;
}

export function PublicLayout({ children, title }: PublicLayoutProps) {
  const navItems = [
    { href: "/", label: "الرئيسية", icon: <Home className="h-5 w-5" /> },
    { href: "/about", label: "من نحن", icon: <Info className="h-5 w-5" /> },
    { href: "/faq", label: "الأسئلة الشائعة", icon: <HelpCircle className="h-5 w-5" /> },
    { href: "/help-center", label: "مركز المساعدة", icon: <HelpCircle className="h-5 w-5" /> },
    { href: "/contact", label: "اتصل بنا", icon: <MessageSquare className="h-5 w-5" /> },
  ];
  
  return (
    <div className="min-h-screen flex flex-col bg-muted/20 rtl">
      <header className="bg-background border-b sticky top-0 z-10">
        <div className="container mx-auto p-4 flex items-center justify-between">
          <Link href="/">
            <div className="flex items-center space-x-2 cursor-pointer">
              <span className="text-2xl font-bold bg-gradient-to-r from-primary to-primary/60 text-transparent bg-clip-text">
                صقر تي في
              </span>
            </div>
          </Link>
          
          <div className="md:hidden">
            <Sheet>
              <SheetTrigger asChild>
                <Button variant="ghost" size="icon">
                  <Menu className="h-5 w-5" />
                </Button>
              </SheetTrigger>
              <SheetContent side="right" className="p-0 text-right">
                <nav className="flex flex-col p-4">
                  <div className="mb-4 pb-4 border-b flex justify-between items-center">
                    <X className="h-5 w-5" />
                    <span className="text-xl font-bold">القائمة</span>
                  </div>
                  {navItems.map((item) => (
                    <Link key={item.href} href={item.href}>
                      <a className="flex items-center justify-end space-x-2 space-x-reverse py-2 px-4 hover:bg-muted rounded-md text-right">
                        {item.icon}
                        <span>{item.label}</span>
                      </a>
                    </Link>
                  ))}
                  <div className="mt-4 pt-4 border-t">
                    <Button className="w-full" asChild>
                      <Link href="/auth">تسجيل الدخول</Link>
                    </Button>
                  </div>
                </nav>
              </SheetContent>
            </Sheet>
          </div>
          
          <nav className="hidden md:flex items-center space-x-6 space-x-reverse">
            {navItems.map((item) => (
              <Link key={item.href} href={item.href}>
                <a className="text-sm font-medium transition-colors hover:text-primary">
                  {item.label}
                </a>
              </Link>
            ))}
            <Button size="sm" asChild>
              <Link href="/auth">تسجيل الدخول</Link>
            </Button>
          </nav>
        </div>
      </header>
      
      <main className="flex-1">
        {title && (
          <div className="bg-muted/50 py-6">
            <div className="container mx-auto px-4">
              <h1 className="text-3xl font-bold text-right">{title}</h1>
            </div>
          </div>
        )}
        {children}
      </main>
      
      <footer className="bg-muted/20 border-t py-8">
        <div className="container mx-auto px-4">
          <div className="grid grid-cols-1 md:grid-cols-4 gap-8 text-right">
            <div>
              <h3 className="font-bold text-lg mb-4">صقر تي في</h3>
              <p className="text-muted-foreground">
                منصة بث محتوى متكاملة توفر أفلام ومسلسلات وقنوات تلفزيونية ومباريات رياضية مباشرة.
              </p>
            </div>
            
            <div>
              <h3 className="font-bold text-lg mb-4">روابط سريعة</h3>
              <ul className="space-y-2">
                <li>
                  <Link href="/">
                    <a className="text-muted-foreground hover:text-primary transition-colors">الرئيسية</a>
                  </Link>
                </li>
                <li>
                  <Link href="/about">
                    <a className="text-muted-foreground hover:text-primary transition-colors">من نحن</a>
                  </Link>
                </li>
                <li>
                  <Link href="/faq">
                    <a className="text-muted-foreground hover:text-primary transition-colors">الأسئلة الشائعة</a>
                  </Link>
                </li>
              </ul>
            </div>
            
            <div>
              <h3 className="font-bold text-lg mb-4">المساعدة</h3>
              <ul className="space-y-2">
                <li>
                  <Link href="/help-center">
                    <a className="text-muted-foreground hover:text-primary transition-colors">مركز المساعدة</a>
                  </Link>
                </li>
                <li>
                  <Link href="/contact">
                    <a className="text-muted-foreground hover:text-primary transition-colors">اتصل بنا</a>
                  </Link>
                </li>
                <li>
                  <Link href="/privacy">
                    <a className="text-muted-foreground hover:text-primary transition-colors">سياسة الخصوصية</a>
                  </Link>
                </li>
                <li>
                  <Link href="/terms">
                    <a className="text-muted-foreground hover:text-primary transition-colors">شروط الاستخدام</a>
                  </Link>
                </li>
              </ul>
            </div>
            
            <div>
              <h3 className="font-bold text-lg mb-4">تواصل معنا</h3>
              <ul className="space-y-2">
                <li className="text-muted-foreground">info@saqrtv.com</li>
                <li className="text-muted-foreground">+966 5XXXXXXXX</li>
                <li className="text-muted-foreground">المملكة العربية السعودية</li>
              </ul>
            </div>
          </div>
          
          <div className="mt-8 pt-8 border-t text-center">
            <p className="text-muted-foreground">
              &copy; {new Date().getFullYear()} صقر تي في. جميع الحقوق محفوظة.
            </p>
          </div>
        </div>
      </footer>
    </div>
  );
}