import React, { useState, useRef } from "react";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { UploadCloud, X, FileText } from "lucide-react";
import { cn } from "@/lib/utils";

interface FileUploadProps {
  id: string;
  label: string;
  accept?: string;
  maxSize?: number; // in MB
  onChange: (file: File | null) => void;
  className?: string;
  error?: string;
}

export function FileUpload({
  id,
  label,
  accept,
  maxSize = 5, // Default max size is 5MB
  onChange,
  className,
  error,
}: FileUploadProps) {
  const [file, setFile] = useState<File | null>(null);
  const [fileError, setFileError] = useState<string | null>(null);
  const inputRef = useRef<HTMLInputElement>(null);

  const handleFileChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const selectedFile = e.target.files?.[0] || null;
    
    if (!selectedFile) {
      setFile(null);
      onChange(null);
      return;
    }
    
    // Check file size
    if (maxSize && selectedFile.size > maxSize * 1024 * 1024) {
      setFileError(`File size exceeds ${maxSize}MB limit`);
      setFile(null);
      onChange(null);
      return;
    }
    
    setFileError(null);
    setFile(selectedFile);
    onChange(selectedFile);
  };

  const clearFile = () => {
    setFile(null);
    setFileError(null);
    onChange(null);
    if (inputRef.current) {
      inputRef.current.value = '';
    }
  };

  const triggerFileInput = () => {
    inputRef.current?.click();
  };

  return (
    <div className={cn("space-y-2", className)}>
      <Input
        id={id}
        type="file"
        accept={accept}
        ref={inputRef}
        onChange={handleFileChange}
        className="hidden"
      />
      
      {!file ? (
        <div 
          onClick={triggerFileInput}
          className={cn(
            "border-2 border-dashed rounded-md p-6 flex flex-col items-center justify-center gap-2 cursor-pointer transition-colors",
            "hover:border-primary/50 hover:bg-background/50",
            fileError || error ? "border-destructive/50 bg-destructive/10" : "border-border bg-background"
          )}
        >
          <UploadCloud className="h-10 w-10 text-muted-foreground" />
          <p className="text-sm font-medium">{label}</p>
          <p className="text-xs text-muted-foreground">
            {maxSize && `Max size: ${maxSize}MB`}
          </p>
          {(fileError || error) && (
            <p className="text-xs text-destructive">
              {fileError || error}
            </p>
          )}
        </div>
      ) : (
        <div className="border rounded-md p-3 flex items-center justify-between">
          <div className="flex items-center gap-2">
            <div className="h-10 w-10 rounded-md bg-primary/10 flex items-center justify-center">
              <FileText className="h-5 w-5 text-primary" />
            </div>
            <div className="space-y-1 text-left">
              <p className="text-sm font-medium truncate max-w-[150px]">
                {file.name}
              </p>
              <p className="text-xs text-muted-foreground">
                {(file.size / 1024 / 1024).toFixed(2)}MB
              </p>
            </div>
          </div>
          <Button 
            type="button" 
            variant="ghost" 
            size="icon" 
            onClick={clearFile}
          >
            <X className="h-4 w-4" />
          </Button>
        </div>
      )}
    </div>
  );
}