import { useState } from "react";
import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";
import { DashboardLayout } from "@/components/dashboard/layout";
import { Button } from "@/components/ui/button";
import { Calendar } from "@/components/ui/calendar";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { Dialog, DialogContent, DialogDescription, DialogFooter, DialogHeader, DialogTitle } from "@/components/ui/dialog";
import { Match } from "@shared/schema";
import { Badge } from "@/components/ui/badge";
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { Separator } from "@/components/ui/separator";
import { Loader2, Calendar as CalendarIcon, Clock, MapPin, RefreshCw, Edit, Trash2, Plus } from "lucide-react";
import { apiRequest } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import { format, isSameDay, parseISO, isAfter, isBefore, isToday } from "date-fns";
import { MatchFetcherModal } from "@/components/modals/match-fetcher-modal";
import { AlertDialog, AlertDialogAction, AlertDialogCancel, AlertDialogContent, AlertDialogDescription, AlertDialogFooter, AlertDialogHeader, AlertDialogTitle } from "@/components/ui/alert-dialog";

export default function MatchSchedulePage() {
  const { toast } = useToast();
  const queryClient = useQueryClient();
  const [selectedDate, setSelectedDate] = useState<Date | undefined>(new Date());
  const [activeTab, setActiveTab] = useState("upcoming");
  const [deleteMatchId, setDeleteMatchId] = useState<number | null>(null);
  const [updateMatchId, setUpdateMatchId] = useState<number | null>(null);
  const [homeScore, setHomeScore] = useState<string>("");
  const [awayScore, setAwayScore] = useState<string>("");
  const [fetcherOpen, setFetcherOpen] = useState(false);

  // Fetch matches
  const { data: matches, isLoading } = useQuery({
    queryKey: ["/api/matches"],
    select: (data: Match[]) => {
      // Sort matches by start time
      return [...data].sort((a, b) => {
        return new Date(a.startTime).getTime() - new Date(b.startTime).getTime();
      });
    }
  });

  // Fetch match to update if needed
  const { data: matchToUpdate } = useQuery({
    queryKey: ["/api/matches", updateMatchId],
    enabled: updateMatchId !== null,
  });

  // Set up mutations
  const updateScoreMutation = useMutation({
    mutationFn: async ({ id, scoreHome, scoreAway }: { id: number, scoreHome: number, scoreAway: number }) => {
      const res = await apiRequest("PATCH", `/api/matches/${id}/score`, { scoreHome, scoreAway });
      return await res.json();
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ["/api/matches"] });
      toast({ 
        title: "Score updated",
        description: "Match score has been updated successfully" 
      });
      setUpdateMatchId(null);
      setHomeScore("");
      setAwayScore("");
    },
    onError: (error: Error) => {
      toast({ 
        title: "Failed to update score", 
        description: error.message,
        variant: "destructive" 
      });
    }
  });

  const updateStatusMutation = useMutation({
    mutationFn: async ({ id, status }: { id: number, status: string }) => {
      const res = await apiRequest("PATCH", `/api/matches/${id}/status`, { status });
      return await res.json();
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ["/api/matches"] });
      toast({ 
        title: "Status updated",
        description: "Match status has been updated successfully" 
      });
    },
    onError: (error: Error) => {
      toast({ 
        title: "Failed to update status", 
        description: error.message,
        variant: "destructive" 
      });
    }
  });

  const deleteMatchMutation = useMutation({
    mutationFn: async (id: number) => {
      const res = await apiRequest("DELETE", `/api/matches/${id}`);
      return res.ok;
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ["/api/matches"] });
      toast({ 
        title: "Match deleted",
        description: "Match has been removed from the schedule" 
      });
      setDeleteMatchId(null);
    },
    onError: (error: Error) => {
      toast({ 
        title: "Failed to delete match", 
        description: error.message,
        variant: "destructive" 
      });
    }
  });

  // Filter matches based on tab and selected date
  const filteredMatches = matches?.filter(match => {
    // Ensure we have valid startTime
    if (!match.startTime) return false;
    
    const matchDate = new Date(match.startTime);
    
    // Apply date filter
    if (selectedDate && !isSameDay(matchDate, selectedDate)) {
      return false;
    }
    
    // Apply tab filter
    if (activeTab === "upcoming") {
      return match.status === "scheduled" || match.status === "postponed";
    } else if (activeTab === "live") {
      return match.status === "live";
    } else if (activeTab === "completed") {
      return match.status === "completed";
    }
    
    return true;
  });

  // Helper functions for match display
  const handleDeleteMatch = (match: Match) => {
    setDeleteMatchId(match.id);
  };

  const handleUpdateStatus = (match: Match, newStatus: string) => {
    updateStatusMutation.mutate({ id: match.id, status: newStatus });
  };

  const handleUpdateScore = () => {
    if (updateMatchId && homeScore.trim() !== "" && awayScore.trim() !== "") {
      updateScoreMutation.mutate({
        id: updateMatchId,
        scoreHome: parseInt(homeScore),
        scoreAway: parseInt(awayScore)
      });
    }
  };

  const formatTimeStatus = (match: Match) => {
    const startTime = parseISO(match.startTime);
    const endTime = match.endTime ? parseISO(match.endTime) : null;
    const now = new Date();
    
    if (match.status === "live") {
      return "LIVE NOW";
    } else if (match.status === "completed") {
      return "FULL TIME";
    } else if (match.status === "postponed") {
      return "POSTPONED";
    } else if (match.status === "cancelled") {
      return "CANCELLED";
    } else if (isAfter(startTime, now)) {
      return `Starts ${format(startTime, "h:mm a")}`;
    } else if (endTime && isAfter(endTime, now)) {
      return "IN PROGRESS";
    } else {
      return "SCHEDULED";
    }
  };

  const formatScore = (match: Match) => {
    if (match.status === "scheduled" || match.status === "postponed") {
      return "vs";
    } else if (match.scoreHome !== null && match.scoreAway !== null) {
      return `${match.scoreHome} - ${match.scoreAway}`;
    } else {
      return "0 - 0";
    }
  };

  const getStatusBadgeColor = (status: string) => {
    switch (status) {
      case "live":
        return "bg-red-500 hover:bg-red-600";
      case "completed":
        return "bg-green-500 hover:bg-green-600";
      case "scheduled":
        return "bg-blue-500 hover:bg-blue-600";
      case "postponed":
        return "bg-yellow-500 hover:bg-yellow-600";
      case "cancelled":
        return "bg-gray-500 hover:bg-gray-600";
      default:
        return "bg-gray-500 hover:bg-gray-600";
    }
  };

  return (
    <DashboardLayout title="Match Schedule" subtitle="View and manage upcoming, live, and completed matches">
      <div className="grid gap-6">
        <div className="flex flex-col md:flex-row md:justify-between md:items-center gap-4">
          <div>
            <Tabs 
              value={activeTab} 
              onValueChange={setActiveTab}
              className="w-full"
            >
              <TabsList>
                <TabsTrigger value="upcoming">Upcoming</TabsTrigger>
                <TabsTrigger value="live">Live</TabsTrigger>
                <TabsTrigger value="completed">Completed</TabsTrigger>
                <TabsTrigger value="all">All</TabsTrigger>
              </TabsList>
            </Tabs>
          </div>
          
          <div className="flex space-x-2">
            <Button 
              variant="outline" 
              size="sm"
              onClick={() => setSelectedDate(new Date())}
              className={isToday(selectedDate || new Date()) ? "border-primary" : ""}
            >
              <CalendarIcon className="mr-2 h-4 w-4" />
              Today
            </Button>
            
            <Button 
              variant="default" 
              size="sm"
              onClick={() => setFetcherOpen(true)}
            >
              <RefreshCw className="mr-2 h-4 w-4" />
              Fetch Matches
            </Button>
          </div>
        </div>
        
        <div className="grid grid-cols-1 md:grid-cols-[250px_1fr] gap-6">
          <Card>
            <CardHeader>
              <CardTitle>Select Date</CardTitle>
            </CardHeader>
            <CardContent>
              <Calendar
                mode="single"
                selected={selectedDate}
                onSelect={setSelectedDate}
                className="rounded-md border"
              />
            </CardContent>
          </Card>
          
          <div className="space-y-6">
            {isLoading ? (
              <div className="flex justify-center items-center h-64">
                <Loader2 className="h-8 w-8 animate-spin text-primary" />
              </div>
            ) : filteredMatches && filteredMatches.length > 0 ? (
              <div className="space-y-4">
                {filteredMatches.map(match => (
                  <Card key={match.id} className="overflow-hidden">
                    <div className="grid grid-cols-1 md:grid-cols-[1fr_auto] bg-muted/20">
                      <div className="p-4">
                        <div className="flex items-center gap-2 mb-2">
                          <Badge className={`${getStatusBadgeColor(match.status)} text-white`}>
                            {match.status.toUpperCase()}
                          </Badge>
                          <span className="text-sm text-muted-foreground">
                            {formatTimeStatus(match)}
                          </span>
                        </div>
                        
                        <h3 className="text-xl font-medium mb-1">{match.title}</h3>
                        
                        <div className="flex items-center text-sm text-muted-foreground mb-4">
                          {match.competition && (
                            <div className="flex items-center mr-4">
                              {match.competition}
                            </div>
                          )}
                          {match.venue && (
                            <div className="flex items-center">
                              <MapPin className="h-3 w-3 mr-1" /> 
                              {match.venue}
                            </div>
                          )}
                        </div>
                        
                        <div className="flex items-center justify-between">
                          <div className="text-center md:text-left">
                            <div className="font-medium">{match.teamHome}</div>
                            <div className="text-sm text-muted-foreground">Home</div>
                          </div>
                          
                          <div className="text-xl font-bold mx-4">
                            {formatScore(match)}
                          </div>
                          
                          <div className="text-center md:text-right">
                            <div className="font-medium">{match.teamAway}</div>
                            <div className="text-sm text-muted-foreground">Away</div>
                          </div>
                        </div>
                      </div>
                      
                      <div className="flex flex-row md:flex-col items-center justify-end gap-2 p-4 bg-muted/10">
                        {match.status === "scheduled" && (
                          <Button 
                            variant="outline" 
                            size="sm"
                            onClick={() => handleUpdateStatus(match, "live")}
                          >
                            Set Live
                          </Button>
                        )}
                        
                        {match.status === "live" && (
                          <Button 
                            variant="outline" 
                            size="sm"
                            onClick={() => handleUpdateStatus(match, "completed")}
                          >
                            End Match
                          </Button>
                        )}
                        
                        {(match.status === "live" || match.status === "completed") && (
                          <Button
                            variant="outline"
                            size="sm"
                            onClick={() => {
                              setUpdateMatchId(match.id);
                              setHomeScore(match.scoreHome?.toString() || "0");
                              setAwayScore(match.scoreAway?.toString() || "0");
                            }}
                          >
                            <Edit className="h-4 w-4 mr-1" />
                            Update Score
                          </Button>
                        )}
                        
                        <Button
                          variant="ghost"
                          size="sm"
                          onClick={() => handleDeleteMatch(match)}
                          className="text-destructive"
                        >
                          <Trash2 className="h-4 w-4" />
                        </Button>
                      </div>
                    </div>
                  </Card>
                ))}
              </div>
            ) : (
              <Card className="flex flex-col items-center justify-center p-8 text-center">
                <div className="rounded-full bg-muted p-3 mb-4">
                  <Calendar className="h-6 w-6 text-muted-foreground" />
                </div>
                <h3 className="text-lg font-medium mb-2">
                  No matches found
                </h3>
                <p className="text-muted-foreground mb-4">
                  {activeTab === "upcoming" 
                    ? "There are no upcoming matches scheduled for this date." 
                    : activeTab === "live" 
                    ? "There are no live matches right now." 
                    : "There are no completed matches for this date."}
                </p>
                <Button 
                  variant="outline" 
                  onClick={() => setFetcherOpen(true)}
                >
                  <Plus className="h-4 w-4 mr-2" />
                  Fetch Matches
                </Button>
              </Card>
            )}
          </div>
        </div>
      </div>
      
      {/* Update score dialog */}
      <Dialog
        open={updateMatchId !== null}
        onOpenChange={(open) => !open && setUpdateMatchId(null)}
      >
        <DialogContent className="sm:max-w-[425px]">
          <DialogHeader>
            <DialogTitle>Update Match Score</DialogTitle>
            <DialogDescription>
              Enter the current score for this match.
            </DialogDescription>
          </DialogHeader>
          <div className="grid gap-4 py-4">
            <div className="grid grid-cols-[1fr_auto_1fr] items-center gap-2">
              <div>
                <Label htmlFor="homeScore">{matchToUpdate?.teamHome || "Home"}</Label>
                <Input
                  id="homeScore"
                  type="number"
                  min="0"
                  value={homeScore}
                  onChange={(e) => setHomeScore(e.target.value)}
                  className="mt-1"
                />
              </div>
              <span className="text-lg font-bold mt-6">-</span>
              <div>
                <Label htmlFor="awayScore">{matchToUpdate?.teamAway || "Away"}</Label>
                <Input
                  id="awayScore"
                  type="number"
                  min="0"
                  value={awayScore}
                  onChange={(e) => setAwayScore(e.target.value)}
                  className="mt-1"
                />
              </div>
            </div>
          </div>
          <DialogFooter>
            <Button 
              variant="outline" 
              onClick={() => setUpdateMatchId(null)}
            >
              Cancel
            </Button>
            <Button onClick={handleUpdateScore}>
              Save changes
            </Button>
          </DialogFooter>
        </DialogContent>
      </Dialog>
      
      {/* Delete confirmation dialog */}
      <AlertDialog
        open={deleteMatchId !== null}
        onOpenChange={(open) => !open && setDeleteMatchId(null)}
      >
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>Are you absolutely sure?</AlertDialogTitle>
            <AlertDialogDescription>
              This action cannot be undone. This will permanently delete the match from the schedule.
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel>Cancel</AlertDialogCancel>
            <AlertDialogAction 
              onClick={() => deleteMatchId && deleteMatchMutation.mutate(deleteMatchId)}
              className="bg-destructive text-destructive-foreground hover:bg-destructive/90"
            >
              Delete
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
      
      {/* Match fetcher modal */}
      <MatchFetcherModal 
        open={fetcherOpen} 
        onOpenChange={setFetcherOpen} 
      />
    </DashboardLayout>
  );
}