import { useState } from "react";
import { DashboardLayout } from "@/components/dashboard/layout";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { AddMatchModal } from "@/components/modals/add-match-modal";
import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";
import { useToast } from "@/hooks/use-toast";
import { apiRequest } from "@/lib/queryClient";
import { Match } from "@shared/schema";
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from "@/components/ui/table";
import { StatusBadge } from "@/components/ui/status-badge";
import { Loader2 } from "lucide-react";
import { AlertDialog, AlertDialogAction, AlertDialogCancel, AlertDialogContent, AlertDialogDescription, AlertDialogFooter, AlertDialogHeader, AlertDialogTitle } from "@/components/ui/alert-dialog";
import { format } from "date-fns";

export default function MatchesPage() {
  const { toast } = useToast();
  const queryClient = useQueryClient();
  const [searchQuery, setSearchQuery] = useState("");
  const [sportFilter, setSportFilter] = useState("all");
  const [statusFilter, setStatusFilter] = useState("all");
  const [showAddModal, setShowAddModal] = useState(false);
  const [matchToDelete, setMatchToDelete] = useState<Match | null>(null);

  const { data: matches = [], isLoading } = useQuery({
    queryKey: ['/api/matches'],
  });

  const deleteMatchMutation = useMutation({
    mutationFn: async (id: number) => {
      await apiRequest("DELETE", `/api/matches/${id}`);
      return id;
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/matches'] });
      queryClient.invalidateQueries({ queryKey: ['/api/recent-content'] });
      queryClient.invalidateQueries({ queryKey: ['/api/stats'] });
      toast({
        title: "Match deleted",
        description: "The match has been successfully deleted.",
      });
    },
    onError: (error) => {
      toast({
        title: "Failed to delete match",
        description: error.message || "An error occurred while deleting the match.",
        variant: "destructive",
      });
    },
  });

  const filteredMatches = matches.filter(match => {
    const matchesSearch = match.title?.toLowerCase().includes(searchQuery.toLowerCase());
    const matchesSport = sportFilter === 'all' || match.sport === sportFilter;
    const matchesStatus = statusFilter === 'all' || match.status === statusFilter;
    return matchesSearch && matchesSport && matchesStatus;
  });

  const uniqueSports = Array.from(new Set(matches.map(match => match.sport).filter(Boolean)));
  const uniqueStatuses = Array.from(new Set(matches.map(match => match.status).filter(Boolean)));

  const handleDeleteMatch = (match: Match) => {
    setMatchToDelete(match);
  };

  const confirmDelete = () => {
    if (matchToDelete) {
      deleteMatchMutation.mutate(matchToDelete.id);
      setMatchToDelete(null);
    }
  };

  return (
    <DashboardLayout
      title="Live Matches"
      subtitle="Manage your live sports matches"
    >
      <div className="mb-6 flex flex-col md:flex-row gap-4 justify-between">
        <div className="flex flex-col md:flex-row gap-4 md:items-center">
          <Input
            placeholder="Search matches..."
            className="max-w-sm"
            value={searchQuery}
            onChange={(e) => setSearchQuery(e.target.value)}
          />
          <Select value={sportFilter} onValueChange={setSportFilter}>
            <SelectTrigger className="max-w-[180px]">
              <SelectValue placeholder="All Sports" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="all">All Sports</SelectItem>
              {uniqueSports.map(sport => (
                <SelectItem key={sport} value={sport as string}>{sport}</SelectItem>
              ))}
            </SelectContent>
          </Select>
          <Select value={statusFilter} onValueChange={setStatusFilter}>
            <SelectTrigger className="max-w-[180px]">
              <SelectValue placeholder="All Statuses" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="all">All Statuses</SelectItem>
              {uniqueStatuses.map(status => (
                <SelectItem key={status} value={status as string}>{status}</SelectItem>
              ))}
            </SelectContent>
          </Select>
        </div>
        <Button onClick={() => setShowAddModal(true)}>
          <i className="fas fa-plus mr-2"></i> Add Match
        </Button>
      </div>

      <div className="bg-white rounded-lg shadow-sm overflow-hidden">
        {isLoading ? (
          <div className="flex justify-center items-center p-12">
            <Loader2 className="h-8 w-8 animate-spin text-primary" />
          </div>
        ) : filteredMatches.length === 0 ? (
          <div className="flex flex-col items-center justify-center p-12 text-center">
            <i className="fas fa-futbol text-gray-300 text-5xl mb-4"></i>
            <h3 className="text-lg font-medium text-gray-900 mb-1">No matches found</h3>
            <p className="text-gray-500 mb-4">
              {searchQuery || sportFilter !== 'all' || statusFilter !== 'all'
                ? "Try adjusting your search or filter criteria"
                : "Start adding live matches to your collection"}
            </p>
            {!(searchQuery || sportFilter !== 'all' || statusFilter !== 'all') && (
              <Button onClick={() => setShowAddModal(true)}>
                <i className="fas fa-plus mr-2"></i> Add Your First Match
              </Button>
            )}
          </div>
        ) : (
          <Table>
            <TableHeader>
              <TableRow>
                <TableHead>Match</TableHead>
                <TableHead>Sport</TableHead>
                <TableHead>Competition</TableHead>
                <TableHead>Start Time</TableHead>
                <TableHead>Status</TableHead>
                <TableHead className="text-right">Actions</TableHead>
              </TableRow>
            </TableHeader>
            <TableBody>
              {filteredMatches.map((match) => (
                <TableRow key={match.id}>
                  <TableCell className="font-medium">
                    <div className="flex items-center">
                      {match.thumbnail ? (
                        <div
                          className="h-10 w-10 rounded bg-cover bg-center mr-3"
                          style={{ backgroundImage: `url(${match.thumbnail})` }}
                        ></div>
                      ) : (
                        <div className="h-10 w-10 rounded bg-gray-200 flex items-center justify-center mr-3">
                          <i className="fas fa-futbol text-gray-400"></i>
                        </div>
                      )}
                      {match.title}
                    </div>
                  </TableCell>
                  <TableCell className="capitalize">{match.sport || "N/A"}</TableCell>
                  <TableCell>{match.competition || "N/A"}</TableCell>
                  <TableCell>
                    {match.startTime ? format(new Date(match.startTime), 'MMM d, yyyy h:mm a') : "N/A"}
                  </TableCell>
                  <TableCell>
                    <StatusBadge status={(match.status as any) || "scheduled"} />
                  </TableCell>
                  <TableCell className="text-right">
                    <div className="flex justify-end space-x-2">
                      <Button variant="ghost" size="icon" title="Edit">
                        <i className="fas fa-edit text-gray-500 hover:text-primary"></i>
                      </Button>
                      <Button 
                        variant="ghost" 
                        size="icon" 
                        title="Delete" 
                        onClick={() => handleDeleteMatch(match)}
                      >
                        <i className="fas fa-trash text-gray-500 hover:text-red-500"></i>
                      </Button>
                    </div>
                  </TableCell>
                </TableRow>
              ))}
            </TableBody>
          </Table>
        )}
      </div>

      <AddMatchModal
        open={showAddModal}
        onOpenChange={setShowAddModal}
      />

      <AlertDialog open={!!matchToDelete} onOpenChange={() => setMatchToDelete(null)}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>Are you sure?</AlertDialogTitle>
            <AlertDialogDescription>
              This action cannot be undone. This will permanently delete
              the match "{matchToDelete?.title}" from your collection.
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel>Cancel</AlertDialogCancel>
            <AlertDialogAction onClick={confirmDelete} className="bg-red-500 hover:bg-red-600">
              {deleteMatchMutation.isPending ? "Deleting..." : "Delete"}
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </DashboardLayout>
  );
}
