import React, { useEffect, useState } from 'react';
import {
  StyleSheet,
  View,
  Text,
  FlatList,
  ActivityIndicator,
  RefreshControl,
} from 'react-native';
import { SafeAreaView } from 'react-native-safe-area-context';
import { getChannels } from '../services/api';
import ContentCard from '../components/ContentCard';

const ChannelsScreen = ({ navigation }: any) => {
  const [channels, setChannels] = useState([]);
  const [loading, setLoading] = useState(true);
  const [refreshing, setRefreshing] = useState(false);

  const fetchChannels = async () => {
    try {
      setLoading(true);
      const channelsData = await getChannels();
      // Add type property for ContentCard component
      const channelsWithType = channelsData.map((channel: any) => ({
        ...channel,
        type: 'channel',
      }));
      setChannels(channelsWithType);
    } catch (error) {
      console.error('Error fetching channels:', error);
    } finally {
      setLoading(false);
    }
  };

  const handleRefresh = async () => {
    setRefreshing(true);
    await fetchChannels();
    setRefreshing(false);
  };

  useEffect(() => {
    fetchChannels();
  }, []);

  const handleChannelPress = (channel: any) => {
    navigation.navigate('VideoPlayer', {
      videoId: channel.id,
      videoType: 'channel',
      title: channel.name,
    });
  };

  if (loading && !refreshing) {
    return (
      <View style={styles.loadingContainer}>
        <ActivityIndicator size="large" color="#E50914" />
        <Text style={styles.loadingText}>جاري تحميل القنوات...</Text>
      </View>
    );
  }

  return (
    <SafeAreaView style={styles.container}>
      <View style={styles.header}>
        <Text style={styles.headerTitle}>القنوات</Text>
      </View>

      {channels.length === 0 ? (
        <View style={styles.emptyContainer}>
          <Text style={styles.emptyText}>لا توجد قنوات متاحة</Text>
        </View>
      ) : (
        <FlatList
          data={channels}
          numColumns={2}
          refreshControl={
            <RefreshControl refreshing={refreshing} onRefresh={handleRefresh} />
          }
          keyExtractor={(item) => item.id.toString()}
          renderItem={({ item }) => (
            <ContentCard item={item} onPress={() => handleChannelPress(item)} />
          )}
          contentContainerStyle={styles.channelsList}
        />
      )}
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#121212',
  },
  loadingContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#121212',
  },
  loadingText: {
    color: '#fff',
    marginTop: 10,
  },
  header: {
    padding: 15,
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
  },
  headerTitle: {
    fontSize: 22,
    color: '#fff',
    fontWeight: 'bold',
  },
  channelsList: {
    paddingHorizontal: 15,
    paddingBottom: 20,
  },
  emptyContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  emptyText: {
    color: '#fff',
    fontSize: 16,
  },
});

export default ChannelsScreen;