import React, { useEffect, useState, useRef } from 'react';
import {
  StyleSheet,
  View,
  Text,
  TouchableOpacity,
  ActivityIndicator,
  Dimensions,
  BackHandler,
  StatusBar,
  Platform,
  Alert
} from 'react-native';
import { Video, AVPlaybackStatus, ResizeMode } from 'expo-av';
import { NativeStackScreenProps } from '@react-navigation/native-stack';
import { RootStackParamList } from '../../App';
import AdDisplay, { AdType } from '../components/AdDisplay';

type PlayerScreenProps = NativeStackScreenProps<RootStackParamList, 'Player'>;

const { width, height } = Dimensions.get('window');

export default function PlayerScreen({ route, navigation }: PlayerScreenProps) {
  const { videoUrl, title, thumbnail, contentType } = route.params;
  const [status, setStatus] = useState<AVPlaybackStatus | null>(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState('');
  const [isFullscreen, setIsFullscreen] = useState(false);
  const [isPlaying, setIsPlaying] = useState(false);
  const [showControls, setShowControls] = useState(true);
  const [showAd, setShowAd] = useState(true);
  const [adType, setAdType] = useState<'initial' | 'interstitial' | 'rewarded'>('initial');
  const [adLoading, setAdLoading] = useState(false);
  const videoRef = useRef<Video>(null);
  const controlsTimeout = useRef<NodeJS.Timeout | null>(null);
  
  // Hide controls after a period of inactivity
  const hideControlsTimeout = () => {
    if (controlsTimeout.current) {
      clearTimeout(controlsTimeout.current);
    }
    
    controlsTimeout.current = setTimeout(() => {
      if (isPlaying) {
        setShowControls(false);
      }
    }, 3000);
  };
  
  // Track time to show interstitial ads every 5 minutes
  const [lastAdTime, setLastAdTime] = useState(0);
  const adIntervalInMilliseconds = 5 * 60 * 1000; // 5 minutes
  
  // Function to show an ad with proper type
  const showAdWithType = (type: 'initial' | 'interstitial' | 'rewarded') => {
    if (videoRef.current && isPlaying) {
      videoRef.current.pauseAsync();
    }
    setAdType(type);
    setShowAd(true);
    setIsPlaying(false);
    setAdLoading(true);
  };
  
  useEffect(() => {
    // Handle Android back button
    const backHandler = BackHandler.addEventListener('hardwareBackPress', () => {
      if (isFullscreen) {
        setIsFullscreen(false);
        return true;
      } else {
        navigation.goBack();
        return true;
      }
    });
    
    // Show initial ad when the player first loads
    showAdWithType('initial');
    
    // Auto-hide controls when playing
    hideControlsTimeout();
    
    return () => {
      if (controlsTimeout.current) {
        clearTimeout(controlsTimeout.current);
      }
      backHandler.remove();
    };
  }, [isFullscreen, navigation]);
  
  // Check if we should show an ad based on playback time
  useEffect(() => {
    if (status && 'positionMillis' in status && status.positionMillis) {
      const currentPosition = status.positionMillis;
      
      // If more than 5 minutes have passed since the last ad, show an ad
      if (currentPosition - lastAdTime >= adIntervalInMilliseconds) {
        setLastAdTime(currentPosition);
        
        // Only show the ad if we're actually playing
        if (isPlaying) {
          showAdWithType('interstitial');
        }
      }
    }
  }, [status, lastAdTime, isPlaying]);
  
  // Handle ad completion
  const handleAdComplete = () => {
    setShowAd(false);
    setIsPlaying(true);
    
    // Small delay to ensure the player is ready
    setTimeout(() => {
      if (videoRef.current) {
        videoRef.current.playAsync();
      }
    }, 500);
  };
  
  const handlePlaybackStatusUpdate = (status: AVPlaybackStatus) => {
    setStatus(status);
    
    if (status.isLoaded) {
      setLoading(false);
      
      // If we're done loading and the video is supposed to be playing, actually play it
      if (isPlaying && status.shouldPlay === false) {
        videoRef.current?.playAsync();
      }
    } else if (status.error) {
      setError(`حدث خطأ أثناء تشغيل الفيديو: ${status.error}`);
    }
  };
  
  const togglePlayPause = () => {
    if (videoRef.current) {
      if (isPlaying) {
        videoRef.current.pauseAsync();
      } else {
        videoRef.current.playAsync();
      }
      setIsPlaying(!isPlaying);
    }
    
    // Reset the control hide timeout
    hideControlsTimeout();
  };
  
  const toggleFullscreen = () => {
    setIsFullscreen(!isFullscreen);
    
    // Reset the control hide timeout
    hideControlsTimeout();
  };
  
  const handleVideoPress = () => {
    setShowControls(!showControls);
    
    if (showControls) {
      hideControlsTimeout();
    }
  };
  
  const handleBackPress = () => {
    if (isFullscreen) {
      setIsFullscreen(false);
    } else {
      navigation.goBack();
    }
  };
  
  if (error) {
    return (
      <View style={styles.errorContainer}>
        <Text style={styles.errorText}>{error}</Text>
        <TouchableOpacity style={styles.button} onPress={handleBackPress}>
          <Text style={styles.buttonText}>العودة</Text>
        </TouchableOpacity>
      </View>
    );
  }
  
  return (
    <View style={styles.container}>
      <StatusBar hidden={true} />
      
      {showAd ? (
        <AdDisplay 
          onAdComplete={handleAdComplete}
          adType={adType === 'initial' ? AdType.INTERSTITIAL : AdType.INTERSTITIAL}
          isVideoAd={adType === 'interstitial'} 
          durationInSeconds={adType === 'initial' ? 5 : 10}
          showSkipButton={adType !== 'initial'}
        />
      ) : (
        <View style={isFullscreen ? styles.fullscreenVideoContainer : styles.videoContainer}>
          <TouchableOpacity
            activeOpacity={1}
            style={styles.videoWrapper}
            onPress={handleVideoPress}
          >
            <Video
              ref={videoRef}
              source={{ uri: videoUrl }}
              style={styles.video}
              resizeMode={ResizeMode.CONTAIN}
              useNativeControls={false}
              shouldPlay={isPlaying && !showAd}
              isLooping={false}
              onPlaybackStatusUpdate={handlePlaybackStatusUpdate}
              onLoadStart={() => setLoading(true)}
              onError={(error) => {
                console.error('Video playback error:', error);
                setError('فشل تشغيل الفيديو. يرجى التحقق من الاتصال بالإنترنت أو المحاولة لاحقًا.');
              }}
            />
            
            {loading && (
              <View style={styles.loadingOverlay}>
                <ActivityIndicator size="large" color="#E50914" />
                <Text style={styles.loadingText}>جاري تحميل الفيديو...</Text>
              </View>
            )}
          </TouchableOpacity>
          
          {showControls && (
            <View style={styles.controlsOverlay}>
              <View style={styles.topControls}>
                <TouchableOpacity style={styles.backButton} onPress={handleBackPress}>
                  <Text style={styles.controlText}>رجوع</Text>
                </TouchableOpacity>
                <Text style={styles.titleText} numberOfLines={1}>
                  {title || 'فيديو'}
                </Text>
              </View>
              
              <View style={styles.centerControls}>
                <TouchableOpacity style={styles.playPauseButton} onPress={togglePlayPause}>
                  <Text style={styles.playPauseText}>
                    {isPlaying ? '⏸️' : '▶️'}
                  </Text>
                </TouchableOpacity>
              </View>
              
              <View style={styles.bottomControls}>
                <TouchableOpacity style={styles.fullscreenButton} onPress={toggleFullscreen}>
                  <Text style={styles.controlText}>
                    {isFullscreen ? 'تصغير' : 'ملء الشاشة'}
                  </Text>
                </TouchableOpacity>
                
                {status && 'positionMillis' in status && 'durationMillis' in status && status.durationMillis && (
                  <Text style={styles.timeText}>
                    {formatTime(status.positionMillis)} / {formatTime(status.durationMillis)}
                  </Text>
                )}
              </View>
            </View>
          )}
        </View>
      )}
    </View>
  );
}

// Helper function to format milliseconds into MM:SS
function formatTime(milliseconds: number): string {
  const totalSeconds = Math.floor(milliseconds / 1000);
  const minutes = Math.floor(totalSeconds / 60);
  const seconds = totalSeconds % 60;
  return `${minutes}:${seconds < 10 ? '0' : ''}${seconds}`;
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#000',
  },
  videoContainer: {
    height: width * (9 / 16), // 16:9 aspect ratio
    width: width,
    backgroundColor: '#000',
  },
  fullscreenVideoContainer: {
    height: height,
    width: width,
    backgroundColor: '#000',
  },
  videoWrapper: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  video: {
    width: '100%',
    height: '100%',
  },
  loadingOverlay: {
    ...StyleSheet.absoluteFillObject,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
  },
  loadingText: {
    color: 'white',
    marginTop: 10,
  },
  controlsOverlay: {
    ...StyleSheet.absoluteFillObject,
    justifyContent: 'space-between',
    padding: 20,
    backgroundColor: 'rgba(0, 0, 0, 0.4)',
  },
  topControls: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  centerControls: {
    alignItems: 'center',
    justifyContent: 'center',
  },
  bottomControls: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  backButton: {
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    paddingHorizontal: 12,
    paddingVertical: 6,
    borderRadius: 4,
  },
  playPauseButton: {
    width: 50,
    height: 50,
    borderRadius: 25,
    backgroundColor: 'rgba(229, 9, 20, 0.7)',
    justifyContent: 'center',
    alignItems: 'center',
  },
  playPauseText: {
    fontSize: 24,
    color: 'white',
  },
  fullscreenButton: {
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    paddingHorizontal: 12,
    paddingVertical: 6,
    borderRadius: 4,
  },
  controlText: {
    color: 'white',
    fontWeight: 'bold',
  },
  titleText: {
    color: 'white',
    fontWeight: 'bold',
    fontSize: 16,
    maxWidth: '70%',
    textAlign: 'right',
  },
  timeText: {
    color: 'white',
  },
  errorContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#121212',
    padding: 20,
  },
  errorText: {
    color: 'white',
    textAlign: 'center',
    marginBottom: 20,
  },
  button: {
    backgroundColor: '#E50914',
    paddingHorizontal: 20,
    paddingVertical: 10,
    borderRadius: 4,
  },
  buttonText: {
    color: 'white',
    fontWeight: 'bold',
  }
});