import { users, type User, type InsertUser } from "@shared/schema";
import { movies, type Movie, type InsertMovie } from "@shared/schema";
import { series, type Series, type InsertSeries } from "@shared/schema";
import { episodes, type Episode, type InsertEpisode } from "@shared/schema";
import { channels, type Channel, type InsertChannel } from "@shared/schema";
import { matches, type Match, type InsertMatch } from "@shared/schema";
import { categories, type Category, type InsertCategory } from "@shared/schema";
import { subcategories, type Subcategory, type InsertSubcategory } from "@shared/schema";
import { notifications, type Notification, type InsertNotification } from "@shared/schema";
import { siteSettings, type SiteSettings, type InsertSiteSettings } from "@shared/schema";
import session from "express-session";
import createMemoryStore from "memorystore";
import { drizzle } from "drizzle-orm/postgres-js";
import { eq, desc, and, sql } from "drizzle-orm";
import postgres from "postgres";
import connectPg from "connect-pg-simple";

// Initialize memory store for session
const MemoryStore = createMemoryStore(session);

// Initialize PostgreSQL connection for production use
const connectionString = process.env.DATABASE_URL;
const client = postgres(connectionString as string);
const db = drizzle(client);
const PostgresSessionStore = connectPg(session);

// Interface for storage operations
export interface IStorage {
  // User operations
  getUser(id: number): Promise<User | undefined>;
  getUserByUsername(username: string): Promise<User | undefined>;
  getUsers(): Promise<User[]>;
  createUser(user: InsertUser): Promise<User>;
  updateUserPassword(id: number, password: string): Promise<User | undefined>;
  
  // Movie operations
  getMovies(): Promise<Movie[]>;
  getMovie(id: number): Promise<Movie | undefined>;
  createMovie(movie: InsertMovie): Promise<Movie>;
  updateMovie(id: number, movie: Partial<InsertMovie>): Promise<Movie | undefined>;
  deleteMovie(id: number): Promise<boolean>;
  
  // Series operations
  getAllSeries(): Promise<Series[]>;
  getSeries(id: number): Promise<Series | undefined>;
  createSeries(series: InsertSeries): Promise<Series>;
  updateSeries(id: number, series: Partial<InsertSeries>): Promise<Series | undefined>;
  deleteSeries(id: number): Promise<boolean>;
  
  // Episode operations
  getEpisodes(seriesId: number): Promise<Episode[]>;
  getEpisode(id: number): Promise<Episode | undefined>;
  createEpisode(episode: InsertEpisode): Promise<Episode>;
  updateEpisode(id: number, episode: Partial<InsertEpisode>): Promise<Episode | undefined>;
  deleteEpisode(id: number): Promise<boolean>;
  
  // Channel operations
  getChannels(): Promise<Channel[]>;
  getChannel(id: number): Promise<Channel | undefined>;
  createChannel(channel: InsertChannel): Promise<Channel>;
  updateChannel(id: number, channel: Partial<InsertChannel>): Promise<Channel | undefined>;
  deleteChannel(id: number): Promise<boolean>;
  
  // Match operations
  getMatches(): Promise<Match[]>;
  getMatch(id: number): Promise<Match | undefined>;
  createMatch(match: InsertMatch): Promise<Match>;
  updateMatch(id: number, match: Partial<InsertMatch>): Promise<Match | undefined>;
  deleteMatch(id: number): Promise<boolean>;
  
  // Category operations
  getCategories(): Promise<Category[]>;
  getCategory(id: number): Promise<Category | undefined>;
  createCategory(category: InsertCategory): Promise<Category>;
  updateCategory(id: number, category: Partial<InsertCategory>): Promise<Category | undefined>;
  deleteCategory(id: number): Promise<boolean>;
  
  // Subcategory operations
  getSubcategories(): Promise<Subcategory[]>;
  getSubcategoriesByType(type: string): Promise<Subcategory[]>;
  getSubcategoriesByParent(parentCategoryId: number): Promise<Subcategory[]>;
  getSubcategory(id: number): Promise<Subcategory | undefined>;
  createSubcategory(subcategory: InsertSubcategory): Promise<Subcategory>;
  updateSubcategory(id: number, subcategory: Partial<InsertSubcategory>): Promise<Subcategory | undefined>;
  deleteSubcategory(id: number): Promise<boolean>;
  
  // Notification operations
  getNotifications(): Promise<Notification[]>;
  getNotification(id: number): Promise<Notification | undefined>;
  createNotification(notification: InsertNotification): Promise<Notification>;
  markNotificationAsRead(id: number): Promise<Notification | undefined>;
  deleteNotification(id: number): Promise<boolean>;
  
  // Content operations
  getRecentContent(limit?: number): Promise<(Movie | Series | Channel | Match)[]>;
  
  // Settings operations
  getSettings(): Promise<SiteSettings | undefined>;
  updateSettings(settings: Partial<InsertSiteSettings>): Promise<SiteSettings>;
  
  // Required for authentication
  sessionStore: any; // Using any for session store since Express types can vary
}

export class MemStorage implements IStorage {
  private users: Map<number, User>;
  private movies: Map<number, Movie>;
  private seriesList: Map<number, Series>;
  private episodes: Map<number, Episode>;
  private channels: Map<number, Channel>;
  private matches: Map<number, Match>;
  private categories: Map<number, Category>;
  private subcategories: Map<number, Subcategory>;
  private notificationsList: Map<number, Notification>;
  private siteSettings: SiteSettings | undefined;
  
  sessionStore: any; // Using any for session store since Express types can vary
  private currentIds: {
    users: number;
    movies: number;
    series: number;
    episodes: number;
    channels: number;
    matches: number;
    categories: number;
    subcategories: number;
    notifications: number;
  };

  constructor() {
    this.users = new Map();
    this.movies = new Map();
    this.seriesList = new Map();
    this.episodes = new Map();
    this.channels = new Map();
    this.matches = new Map();
    this.categories = new Map();
    this.subcategories = new Map();
    this.notificationsList = new Map();
    
    this.currentIds = {
      users: 1,
      movies: 1,
      series: 1,
      episodes: 1,
      channels: 1,
      matches: 1,
      categories: 1,
      subcategories: 1,
      notifications: 1
    };
    
    this.sessionStore = new MemoryStore({
      checkPeriod: 86400000 // 24 hours
    });
    
    // Add a default admin user
    this.createUser({
      username: "admin",
      password: "password123" // This will be hashed in auth.ts
    });
    
    // Add some default categories
    this.createCategory({ name: "Action Movies", type: "movie" });
    this.createCategory({ name: "Drama Series", type: "series" });
    this.createCategory({ name: "News Channels", type: "channel" });
    this.createCategory({ name: "Football Matches", type: "match" });
    
    // Initialize default site settings
    this.siteSettings = {
      id: 1,
      siteName: "Saqr TV",
      siteDescription: "Streaming platform for movies, series, channels and live matches",
      siteKeywords: "streaming, movies, series, tv, channels, live matches",
      siteLogo: null,
      siteFavicon: null,
      appFilePath: null,
      appFileName: null,
      appVersion: null,
      maintenance: false,
      updatedAt: new Date()
    };
  }

  // User operations
  async getUser(id: number): Promise<User | undefined> {
    return this.users.get(id);
  }

  async getUserByUsername(username: string): Promise<User | undefined> {
    return Array.from(this.users.values()).find(
      (user) => user.username === username,
    );
  }
  
  async getUsers(): Promise<User[]> {
    return Array.from(this.users.values());
  }

  async createUser(insertUser: InsertUser): Promise<User> {
    const id = this.currentIds.users++;
    const now = new Date();
    
    // For admin user (first user), use the password directly as it will be hashed in auth.ts
    // Otherwise, use the password that's already hashed
    const user: User = {
      ...insertUser,
      id,
      isAdmin: true,
      createdAt: now
    };
    this.users.set(id, user);
    return user;
  }
  
  async updateUserPassword(id: number, password: string): Promise<User | undefined> {
    const user = this.users.get(id);
    if (!user) return undefined;
    
    const updatedUser: User = {
      ...user,
      password
    };
    this.users.set(id, updatedUser);
    return updatedUser;
  }

  // Movie operations
  async getMovies(): Promise<Movie[]> {
    return Array.from(this.movies.values());
  }

  async getMovie(id: number): Promise<Movie | undefined> {
    return this.movies.get(id);
  }

  async createMovie(insertMovie: InsertMovie): Promise<Movie> {
    const id = this.currentIds.movies++;
    const now = new Date();
    const movie: Movie = {
      ...insertMovie,
      id,
      createdAt: now
    };
    this.movies.set(id, movie);
    return movie;
  }

  async updateMovie(id: number, movieUpdate: Partial<InsertMovie>): Promise<Movie | undefined> {
    const movie = this.movies.get(id);
    if (!movie) return undefined;
    
    const updatedMovie: Movie = {
      ...movie,
      ...movieUpdate
    };
    this.movies.set(id, updatedMovie);
    return updatedMovie;
  }

  async deleteMovie(id: number): Promise<boolean> {
    return this.movies.delete(id);
  }

  // Series operations
  async getAllSeries(): Promise<Series[]> {
    return Array.from(this.seriesList.values());
  }

  async getSeries(id: number): Promise<Series | undefined> {
    return this.seriesList.get(id);
  }

  async createSeries(insertSeries: InsertSeries): Promise<Series> {
    const id = this.currentIds.series++;
    const now = new Date();
    const series: Series = {
      ...insertSeries,
      id,
      createdAt: now
    };
    this.seriesList.set(id, series);
    return series;
  }

  async updateSeries(id: number, seriesUpdate: Partial<InsertSeries>): Promise<Series | undefined> {
    const series = this.seriesList.get(id);
    if (!series) return undefined;
    
    const updatedSeries: Series = {
      ...series,
      ...seriesUpdate
    };
    this.seriesList.set(id, updatedSeries);
    return updatedSeries;
  }

  async deleteSeries(id: number): Promise<boolean> {
    return this.seriesList.delete(id);
  }

  // Episode operations
  async getEpisodes(seriesId: number): Promise<Episode[]> {
    return Array.from(this.episodes.values()).filter(
      (episode) => episode.seriesId === seriesId
    );
  }

  async getEpisode(id: number): Promise<Episode | undefined> {
    return this.episodes.get(id);
  }

  async createEpisode(insertEpisode: InsertEpisode): Promise<Episode> {
    const id = this.currentIds.episodes++;
    const now = new Date();
    const episode: Episode = {
      ...insertEpisode,
      id,
      createdAt: now
    };
    this.episodes.set(id, episode);
    return episode;
  }

  async updateEpisode(id: number, episodeUpdate: Partial<InsertEpisode>): Promise<Episode | undefined> {
    const episode = this.episodes.get(id);
    if (!episode) return undefined;
    
    const updatedEpisode: Episode = {
      ...episode,
      ...episodeUpdate
    };
    this.episodes.set(id, updatedEpisode);
    return updatedEpisode;
  }

  async deleteEpisode(id: number): Promise<boolean> {
    return this.episodes.delete(id);
  }

  // Channel operations
  async getChannels(): Promise<Channel[]> {
    return Array.from(this.channels.values());
  }

  async getChannel(id: number): Promise<Channel | undefined> {
    return this.channels.get(id);
  }

  async createChannel(insertChannel: InsertChannel): Promise<Channel> {
    const id = this.currentIds.channels++;
    const now = new Date();
    const channel: Channel = {
      ...insertChannel,
      id,
      createdAt: now
    };
    this.channels.set(id, channel);
    return channel;
  }

  async updateChannel(id: number, channelUpdate: Partial<InsertChannel>): Promise<Channel | undefined> {
    const channel = this.channels.get(id);
    if (!channel) return undefined;
    
    const updatedChannel: Channel = {
      ...channel,
      ...channelUpdate
    };
    this.channels.set(id, updatedChannel);
    return updatedChannel;
  }

  async deleteChannel(id: number): Promise<boolean> {
    return this.channels.delete(id);
  }

  // Match operations
  async getMatches(): Promise<Match[]> {
    return Array.from(this.matches.values());
  }

  async getMatch(id: number): Promise<Match | undefined> {
    return this.matches.get(id);
  }

  async createMatch(insertMatch: InsertMatch): Promise<Match> {
    const id = this.currentIds.matches++;
    const now = new Date();
    const match: Match = {
      ...insertMatch,
      id,
      createdAt: now
    };
    this.matches.set(id, match);
    return match;
  }

  async updateMatch(id: number, matchUpdate: Partial<InsertMatch>): Promise<Match | undefined> {
    const match = this.matches.get(id);
    if (!match) return undefined;
    
    const updatedMatch: Match = {
      ...match,
      ...matchUpdate
    };
    this.matches.set(id, updatedMatch);
    return updatedMatch;
  }

  async deleteMatch(id: number): Promise<boolean> {
    return this.matches.delete(id);
  }

  // Category operations
  async getCategories(): Promise<Category[]> {
    return Array.from(this.categories.values());
  }

  async getCategory(id: number): Promise<Category | undefined> {
    return this.categories.get(id);
  }

  async createCategory(insertCategory: InsertCategory): Promise<Category> {
    const id = this.currentIds.categories++;
    const category: Category = {
      ...insertCategory,
      id
    };
    this.categories.set(id, category);
    return category;
  }

  async updateCategory(id: number, categoryUpdate: Partial<InsertCategory>): Promise<Category | undefined> {
    const category = this.categories.get(id);
    if (!category) return undefined;
    
    const updatedCategory: Category = {
      ...category,
      ...categoryUpdate
    };
    this.categories.set(id, updatedCategory);
    return updatedCategory;
  }

  async deleteCategory(id: number): Promise<boolean> {
    return this.categories.delete(id);
  }
  
  // Subcategory operations
  async getSubcategories(): Promise<Subcategory[]> {
    return Array.from(this.subcategories.values());
  }
  
  async getSubcategoriesByType(type: string): Promise<Subcategory[]> {
    return Array.from(this.subcategories.values()).filter(
      subcategory => subcategory.type === type
    );
  }
  
  async getSubcategoriesByParent(parentCategoryId: number): Promise<Subcategory[]> {
    return Array.from(this.subcategories.values()).filter(
      subcategory => subcategory.parentCategoryId === parentCategoryId
    );
  }
  
  async getSubcategory(id: number): Promise<Subcategory | undefined> {
    return this.subcategories.get(id);
  }
  
  async createSubcategory(insertSubcategory: InsertSubcategory): Promise<Subcategory> {
    const id = this.currentIds.subcategories++;
    const now = new Date();
    const subcategory: Subcategory = {
      ...insertSubcategory,
      id,
      createdAt: now
    };
    this.subcategories.set(id, subcategory);
    return subcategory;
  }
  
  async updateSubcategory(id: number, subcategoryUpdate: Partial<InsertSubcategory>): Promise<Subcategory | undefined> {
    const subcategory = this.subcategories.get(id);
    if (!subcategory) return undefined;
    
    const updatedSubcategory: Subcategory = {
      ...subcategory,
      ...subcategoryUpdate
    };
    this.subcategories.set(id, updatedSubcategory);
    return updatedSubcategory;
  }
  
  async deleteSubcategory(id: number): Promise<boolean> {
    return this.subcategories.delete(id);
  }

  // Notification operations
  async getNotifications(): Promise<Notification[]> {
    return Array.from(this.notificationsList.values()).sort((a, b) => 
      new Date(b.createdAt).getTime() - new Date(a.createdAt).getTime()
    );
  }

  async getNotification(id: number): Promise<Notification | undefined> {
    return this.notificationsList.get(id);
  }

  async createNotification(insertNotification: InsertNotification): Promise<Notification> {
    const id = this.currentIds.notifications++;
    const now = new Date();
    const notification: Notification = {
      title: insertNotification.title,
      message: insertNotification.message,
      type: insertNotification.type || "info",
      image: insertNotification.image || null,
      link: insertNotification.link || null,
      contentId: insertNotification.contentId || null,
      contentType: insertNotification.contentType || null,
      id,
      read: false,
      createdAt: now
    };
    this.notificationsList.set(id, notification);
    return notification;
  }

  async markNotificationAsRead(id: number): Promise<Notification | undefined> {
    const notification = this.notificationsList.get(id);
    if (!notification) return undefined;
    
    const updatedNotification: Notification = {
      ...notification,
      read: true
    };
    this.notificationsList.set(id, updatedNotification);
    return updatedNotification;
  }

  async deleteNotification(id: number): Promise<boolean> {
    return this.notificationsList.delete(id);
  }

  // Get recent content (movies, series, channels, matches)
  async getRecentContent(limit = 10): Promise<(Movie | Series | Channel | Match)[]> {
    const allContent = [
      ...Array.from(this.movies.values()),
      ...Array.from(this.seriesList.values()),
      ...Array.from(this.channels.values()),
      ...Array.from(this.matches.values())
    ];
    
    return allContent
      .sort((a, b) => new Date(b.createdAt).getTime() - new Date(a.createdAt).getTime())
      .slice(0, limit);
  }
  
  // Settings operations
  async getSettings(): Promise<SiteSettings | undefined> {
    return this.siteSettings;
  }
  
  async updateSettings(settings: Partial<InsertSiteSettings>): Promise<SiteSettings> {
    if (!this.siteSettings) {
      // Initialize with defaults if no settings exist
      this.siteSettings = {
        id: 1,
        siteName: "Saqr TV",
        siteDescription: "Streaming platform for movies, series, channels and live matches",
        siteKeywords: "streaming, movies, series, tv, channels, live matches",
        siteLogo: null,
        siteFavicon: null,
        appFilePath: null,
        appFileName: null,
        appVersion: null,
        maintenance: false,
        updatedAt: new Date()
      };
    }
    
    // Update settings
    const updatedSettings: SiteSettings = {
      ...this.siteSettings,
      ...settings,
      updatedAt: new Date()
    };
    
    this.siteSettings = updatedSettings;
    return updatedSettings;
  }
}

export class PostgresStorage implements IStorage {
  sessionStore: any;

  constructor() {
    // Initialize the session store with PostgreSQL
    this.sessionStore = new PostgresSessionStore({
      conObject: {
        connectionString: connectionString,
        ssl: process.env.NODE_ENV === 'production' ? { rejectUnauthorized: false } : false
      },
      createTableIfMissing: true
    });
  }

  // User operations
  async getUser(id: number): Promise<User | undefined> {
    const result = await db.select().from(users).where(eq(users.id, id)).limit(1);
    return result[0];
  }

  async getUserByUsername(username: string): Promise<User | undefined> {
    const result = await db.select().from(users).where(eq(users.username, username)).limit(1);
    return result[0];
  }

  async getUsers(): Promise<User[]> {
    return await db.select().from(users);
  }

  async createUser(user: InsertUser): Promise<User> {
    const result = await db.insert(users).values(user).returning();
    return result[0];
  }

  async updateUserPassword(id: number, password: string): Promise<User | undefined> {
    const result = await db.update(users).set({ password }).where(eq(users.id, id)).returning();
    return result[0];
  }

  // Movie operations
  async getMovies(): Promise<Movie[]> {
    return await db.select().from(movies);
  }

  async getMovie(id: number): Promise<Movie | undefined> {
    const result = await db.select().from(movies).where(eq(movies.id, id)).limit(1);
    return result[0];
  }

  async createMovie(movie: InsertMovie): Promise<Movie> {
    const result = await db.insert(movies).values(movie).returning();
    return result[0];
  }

  async updateMovie(id: number, movie: Partial<InsertMovie>): Promise<Movie | undefined> {
    const result = await db.update(movies).set(movie).where(eq(movies.id, id)).returning();
    return result[0];
  }

  async deleteMovie(id: number): Promise<boolean> {
    const result = await db.delete(movies).where(eq(movies.id, id));
    return true;
  }

  // Series operations
  async getAllSeries(): Promise<Series[]> {
    return await db.select().from(series);
  }

  async getSeries(id: number): Promise<Series | undefined> {
    const result = await db.select().from(series).where(eq(series.id, id)).limit(1);
    return result[0];
  }

  async createSeries(seriesData: InsertSeries): Promise<Series> {
    const result = await db.insert(series).values(seriesData).returning();
    return result[0];
  }

  async updateSeries(id: number, seriesData: Partial<InsertSeries>): Promise<Series | undefined> {
    const result = await db.update(series).set(seriesData).where(eq(series.id, id)).returning();
    return result[0];
  }

  async deleteSeries(id: number): Promise<boolean> {
    await db.delete(series).where(eq(series.id, id));
    return true;
  }

  // Episode operations
  async getEpisodes(seriesId: number): Promise<Episode[]> {
    return await db.select().from(episodes).where(eq(episodes.seriesId, seriesId));
  }

  async getEpisode(id: number): Promise<Episode | undefined> {
    const result = await db.select().from(episodes).where(eq(episodes.id, id)).limit(1);
    return result[0];
  }

  async createEpisode(episode: InsertEpisode): Promise<Episode> {
    const result = await db.insert(episodes).values(episode).returning();
    return result[0];
  }

  async updateEpisode(id: number, episode: Partial<InsertEpisode>): Promise<Episode | undefined> {
    const result = await db.update(episodes).set(episode).where(eq(episodes.id, id)).returning();
    return result[0];
  }

  async deleteEpisode(id: number): Promise<boolean> {
    await db.delete(episodes).where(eq(episodes.id, id));
    return true;
  }

  // Channel operations
  async getChannels(): Promise<Channel[]> {
    return await db.select().from(channels);
  }

  async getChannel(id: number): Promise<Channel | undefined> {
    const result = await db.select().from(channels).where(eq(channels.id, id)).limit(1);
    return result[0];
  }

  async createChannel(channel: InsertChannel): Promise<Channel> {
    const result = await db.insert(channels).values(channel).returning();
    return result[0];
  }

  async updateChannel(id: number, channel: Partial<InsertChannel>): Promise<Channel | undefined> {
    const result = await db.update(channels).set(channel).where(eq(channels.id, id)).returning();
    return result[0];
  }

  async deleteChannel(id: number): Promise<boolean> {
    await db.delete(channels).where(eq(channels.id, id));
    return true;
  }

  // Match operations
  async getMatches(): Promise<Match[]> {
    return await db.select().from(matches);
  }

  async getMatch(id: number): Promise<Match | undefined> {
    const result = await db.select().from(matches).where(eq(matches.id, id)).limit(1);
    return result[0];
  }

  async createMatch(match: InsertMatch): Promise<Match> {
    const result = await db.insert(matches).values(match).returning();
    return result[0];
  }

  async updateMatch(id: number, match: Partial<InsertMatch>): Promise<Match | undefined> {
    const result = await db.update(matches).set(match).where(eq(matches.id, id)).returning();
    return result[0];
  }

  async deleteMatch(id: number): Promise<boolean> {
    await db.delete(matches).where(eq(matches.id, id));
    return true;
  }

  // Category operations
  async getCategories(): Promise<Category[]> {
    return await db.select().from(categories);
  }

  async getCategory(id: number): Promise<Category | undefined> {
    const result = await db.select().from(categories).where(eq(categories.id, id)).limit(1);
    return result[0];
  }

  async createCategory(category: InsertCategory): Promise<Category> {
    const result = await db.insert(categories).values(category).returning();
    return result[0];
  }

  async updateCategory(id: number, category: Partial<InsertCategory>): Promise<Category | undefined> {
    const result = await db.update(categories).set(category).where(eq(categories.id, id)).returning();
    return result[0];
  }

  async deleteCategory(id: number): Promise<boolean> {
    await db.delete(categories).where(eq(categories.id, id));
    return true;
  }

  // Subcategory operations
  async getSubcategories(): Promise<Subcategory[]> {
    return await db.select().from(subcategories);
  }

  async getSubcategoriesByType(type: string): Promise<Subcategory[]> {
    return await db.select().from(subcategories).where(eq(subcategories.type, type));
  }

  async getSubcategoriesByParent(parentCategoryId: number): Promise<Subcategory[]> {
    return await db.select().from(subcategories).where(eq(subcategories.parentCategoryId, parentCategoryId));
  }

  async getSubcategory(id: number): Promise<Subcategory | undefined> {
    const result = await db.select().from(subcategories).where(eq(subcategories.id, id)).limit(1);
    return result[0];
  }

  async createSubcategory(subcategory: InsertSubcategory): Promise<Subcategory> {
    const result = await db.insert(subcategories).values(subcategory).returning();
    return result[0];
  }

  async updateSubcategory(id: number, subcategory: Partial<InsertSubcategory>): Promise<Subcategory | undefined> {
    const result = await db.update(subcategories).set(subcategory).where(eq(subcategories.id, id)).returning();
    return result[0];
  }

  async deleteSubcategory(id: number): Promise<boolean> {
    await db.delete(subcategories).where(eq(subcategories.id, id));
    return true;
  }

  // Notification operations
  async getNotifications(): Promise<Notification[]> {
    return await db.select().from(notifications).orderBy(desc(notifications.createdAt));
  }

  async getNotification(id: number): Promise<Notification | undefined> {
    const result = await db.select().from(notifications).where(eq(notifications.id, id)).limit(1);
    return result[0];
  }

  async createNotification(notification: InsertNotification): Promise<Notification> {
    const result = await db.insert(notifications).values(notification).returning();
    return result[0];
  }

  async markNotificationAsRead(id: number): Promise<Notification | undefined> {
    const result = await db.update(notifications).set({ read: true }).where(eq(notifications.id, id)).returning();
    return result[0];
  }

  async deleteNotification(id: number): Promise<boolean> {
    await db.delete(notifications).where(eq(notifications.id, id));
    return true;
  }

  // Content operations
  async getRecentContent(limit = 10): Promise<(Movie | Series | Channel | Match)[]> {
    const recentMovies = await db.select().from(movies).orderBy(desc(movies.createdAt)).limit(limit);
    const recentSeries = await db.select().from(series).orderBy(desc(series.createdAt)).limit(limit);
    const recentChannels = await db.select().from(channels).orderBy(desc(channels.createdAt)).limit(limit);
    const recentMatches = await db.select().from(matches).orderBy(desc(matches.createdAt)).limit(limit);
    
    return [...recentMovies, ...recentSeries, ...recentChannels, ...recentMatches]
      .sort((a, b) => new Date(b.createdAt).getTime() - new Date(a.createdAt).getTime())
      .slice(0, limit);
  }

  // Settings operations
  async getSettings(): Promise<SiteSettings | undefined> {
    const result = await db.select().from(siteSettings).limit(1);
    return result[0];
  }

  async updateSettings(settings: Partial<InsertSiteSettings>): Promise<SiteSettings> {
    // Check if settings already exist
    const existingSettings = await this.getSettings();
    
    if (existingSettings) {
      // Update existing settings
      const result = await db.update(siteSettings)
        .set(settings)
        .where(eq(siteSettings.id, existingSettings.id))
        .returning();
      return result[0];
    } else {
      // Create new settings
      const result = await db.insert(siteSettings)
        .values({
          siteName: settings.siteName || "Saqr TV",
          siteDescription: settings.siteDescription || "Your ultimate media streaming platform",
          siteKeywords: settings.siteKeywords || "movies, tv shows, streaming, media",
          siteLogo: settings.siteLogo || null,
          siteFavicon: settings.siteFavicon || null,
          appFilePath: settings.appFilePath || null,
          appFileName: settings.appFileName || null,
          appVersion: settings.appVersion || null,
          maintenance: settings.maintenance || false
        })
        .returning();
      return result[0];
    }
  }
}

// Choose which storage implementation to use based on environment
// For now we'll use the PostgreSQL implementation since we have the database set up
export const storage = process.env.DATABASE_URL 
  ? new PostgresStorage() 
  : new MemStorage();
