import React, { useEffect, useState } from 'react';
import {
  StyleSheet,
  View,
  Text,
  TouchableOpacity,
  ActivityIndicator,
  Dimensions,
  BackHandler,
  Platform,
  StatusBar,
  Linking,
  Alert,
  Image,
} from 'react-native';
import { getMovie, getChannel, getMatch, getSeries, getEpisode } from '../services/api';

const { width, height } = Dimensions.get('window');

const VideoPlayerScreen = ({ route, navigation }: any) => {
  const { videoId, videoType, title, seriesId, episodeId } = route.params;
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState('');
  const [videoUrl, setVideoUrl] = useState('');
  const [contentInfo, setContentInfo] = useState<any>(null);
  const [launchingPlayer, setLaunchingPlayer] = useState(false);

  useEffect(() => {
    // Handle back button press
    const backHandler = BackHandler.addEventListener('hardwareBackPress', () => {
      navigation.goBack();
      return true;
    });

    // Load video data
    const loadVideo = async () => {
      try {
        setLoading(true);
        let content;
        
        if (videoType === 'movie') {
          content = await getMovie(videoId);
        } else if (videoType === 'channel') {
          content = await getChannel(videoId);
        } else if (videoType === 'match') {
          content = await getMatch(videoId);
        } else if (videoType === 'series' && episodeId) {
          content = await getEpisode(episodeId);
        }
        
        setContentInfo(content);
        
        if (content?.videoUrl) {
          setVideoUrl(content.videoUrl);
          // Automatically launch the Saqr Player with the video URL
          launchSaqrPlayer(content.videoUrl, content.title || content.name || title, content.thumbnail, videoType);
        } else {
          setError('لا يوجد رابط فيديو لهذا المحتوى');
        }
      } catch (err) {
        console.error('Error loading video:', err);
        setError('حدث خطأ أثناء تحميل الفيديو');
      } finally {
        setLoading(false);
      }
    };

    loadVideo();

    return () => {
      backHandler.remove();
    };
  }, [videoId, videoType, episodeId, navigation]);

  const launchSaqrPlayer = async (url: string, contentTitle: string, thumbnail?: string, type?: string) => {
    try {
      setLaunchingPlayer(true);
      
      // Construct the deep link URL
      // Format: saqrplayer://play?videoUrl=<url>&title=<title>&thumbnail=<thumbnail>&contentType=<type>
      const deepLinkUrl = `saqrplayer://play?videoUrl=${encodeURIComponent(url)}&title=${encodeURIComponent(contentTitle)}${thumbnail ? `&thumbnail=${encodeURIComponent(thumbnail)}` : ''}${type ? `&contentType=${encodeURIComponent(type)}` : ''}`;
      
      // Check if Saqr Player is installed
      const canOpen = await Linking.canOpenURL(deepLinkUrl);
      
      if (canOpen) {
        // Launch Saqr Player
        await Linking.openURL(deepLinkUrl);
        
        // Go back to the previous screen in the Saqr TV app
        setTimeout(() => {
          navigation.goBack();
        }, 500);
      } else {
        // Saqr Player is not installed, show alert
        Alert.alert(
          'تطبيق صقر بلاير غير مثبت',
          'يرجى تثبيت تطبيق صقر بلاير لمشاهدة المحتوى. هل ترغب في الانتقال إلى صفحة التثبيت؟',
          [
            {
              text: 'لا، شكرًا',
              onPress: () => {
                setLaunchingPlayer(false);
              },
              style: 'cancel',
            },
            {
              text: 'نعم، تثبيت التطبيق',
              onPress: async () => {
                // Open Play Store to install Saqr Player
                const playStoreUrl = 'https://play.google.com/store/apps/details?id=com.saqrplayer.app';
                try {
                  await Linking.openURL(playStoreUrl);
                } catch (error) {
                  console.error('Could not open Play Store:', error);
                  Alert.alert('خطأ', 'حدث خطأ أثناء فتح متجر التطبيقات');
                }
                navigation.goBack();
              },
            },
          ],
          { cancelable: false }
        );
      }
    } catch (error) {
      console.error('Error launching Saqr Player:', error);
      setError('حدث خطأ أثناء تشغيل تطبيق صقر بلاير');
      setLaunchingPlayer(false);
    }
  };

  const handleBackPress = () => {
    navigation.goBack();
  };

  // Display loading screen
  if (loading || launchingPlayer) {
    return (
      <View style={styles.loadingContainer}>
        <ActivityIndicator size="large" color="#E50914" />
        <Text style={styles.loadingText}>
          {launchingPlayer ? 'جاري فتح صقر بلاير...' : 'جاري تحميل الفيديو...'}
        </Text>
      </View>
    );
  }

  // Display error screen
  if (error) {
    return (
      <View style={styles.errorContainer}>
        <Text style={styles.errorText}>{error}</Text>
        <TouchableOpacity style={styles.button} onPress={handleBackPress}>
          <Text style={styles.buttonText}>العودة</Text>
        </TouchableOpacity>
      </View>
    );
  }

  // Display video info screen with play button to launch Saqr Player
  return (
    <View style={styles.container}>
      <StatusBar hidden={false} />
      
      <View style={styles.videoInfoContainer}>
        {contentInfo && (
          <>
            {/* Content image/thumbnail */}
            {contentInfo.thumbnail && (
              <View style={styles.thumbnailContainer}>
                <Image 
                  source={{ uri: contentInfo.thumbnail }} 
                  style={styles.thumbnail} 
                  resizeMode="cover"
                />
              </View>
            )}
            
            <View style={styles.contentInfo}>
              <Text style={styles.titleText}>{contentInfo.title || contentInfo.name || title}</Text>
              
              {contentInfo.description && (
                <Text style={styles.descriptionText}>{contentInfo.description}</Text>
              )}
              
              <View style={styles.metadataContainer}>
                {contentInfo.duration && (
                  <View style={styles.metadataItem}>
                    <Text style={styles.metadataLabel}>المدة:</Text>
                    <Text style={styles.metadataValue}>{contentInfo.duration}</Text>
                  </View>
                )}
                
                {contentInfo.year && (
                  <View style={styles.metadataItem}>
                    <Text style={styles.metadataLabel}>السنة:</Text>
                    <Text style={styles.metadataValue}>{contentInfo.year}</Text>
                  </View>
                )}
                
                {contentInfo.quality && (
                  <View style={styles.metadataItem}>
                    <Text style={styles.metadataLabel}>الجودة:</Text>
                    <Text style={styles.metadataValue}>{contentInfo.quality}</Text>
                  </View>
                )}
              </View>
              
              <TouchableOpacity 
                style={styles.playButton}
                onPress={() => launchSaqrPlayer(
                  videoUrl, 
                  contentInfo.title || contentInfo.name || title,
                  contentInfo.thumbnail,
                  videoType
                )}
              >
                <Text style={styles.playButtonText}>تشغيل في صقر بلاير</Text>
              </TouchableOpacity>
            </View>
          </>
        )}
      </View>
      
      <TouchableOpacity style={styles.backButton} onPress={handleBackPress}>
        <Text style={styles.backButtonText}>العودة</Text>
      </TouchableOpacity>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#000',
  },
  loadingContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#121212',
  },
  loadingText: {
    color: '#fff',
    marginTop: 10,
  },
  errorContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#121212',
    padding: 20,
  },
  errorText: {
    color: '#fff',
    textAlign: 'center',
    marginBottom: 20,
  },
  videoInfoContainer: {
    flex: 1,
    padding: 15,
  },
  thumbnailContainer: {
    width: '100%',
    height: width * 9 / 16, // 16:9 aspect ratio
    marginBottom: 15,
    borderRadius: 8,
    overflow: 'hidden',
  },
  thumbnail: {
    width: '100%',
    height: '100%',
  },
  contentInfo: {
    flex: 1,
  },
  metadataContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    marginBottom: 20,
  },
  metadataItem: {
    flexDirection: 'row',
    marginRight: 15,
    marginBottom: 5,
  },
  metadataLabel: {
    color: '#999',
    marginRight: 5,
  },
  metadataValue: {
    color: '#fff',
  },
  playButton: {
    backgroundColor: '#E50914',
    paddingVertical: 12,
    paddingHorizontal: 20,
    borderRadius: 5,
    alignItems: 'center',
    marginBottom: 20,
  },
  playButtonText: {
    color: '#fff',
    fontWeight: 'bold',
    fontSize: 16,
  },
  backButton: {
    position: 'absolute',
    top: 15,
    left: 15,
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    padding: 10,
    borderRadius: 5,
    zIndex: 100,
  },
  backButtonText: {
    color: '#fff',
  },
  button: {
    backgroundColor: '#E50914',
    padding: 10,
    borderRadius: 5,
    marginTop: 10,
  },
  buttonText: {
    color: '#fff',
  },
  titleText: {
    color: '#fff',
    fontSize: 20,
    fontWeight: 'bold',
    marginBottom: 10,
    textAlign: 'right',
  },
  descriptionText: {
    color: '#ccc',
    fontSize: 14,
    marginBottom: 15,
    lineHeight: 20,
    textAlign: 'right',
  },
});

export default VideoPlayerScreen;